# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['IntegrationJiraArgs', 'IntegrationJira']

@pulumi.input_type
class IntegrationJiraArgs:
    def __init__(__self__, *,
                 password: pulumi.Input[str],
                 project: pulumi.Input[str],
                 url: pulumi.Input[str],
                 api_url: Optional[pulumi.Input[str]] = None,
                 comment_on_event_enabled: Optional[pulumi.Input[bool]] = None,
                 commit_events: Optional[pulumi.Input[bool]] = None,
                 issues_enabled: Optional[pulumi.Input[bool]] = None,
                 jira_auth_type: Optional[pulumi.Input[int]] = None,
                 jira_issue_prefix: Optional[pulumi.Input[str]] = None,
                 jira_issue_regex: Optional[pulumi.Input[str]] = None,
                 jira_issue_transition_automatic: Optional[pulumi.Input[bool]] = None,
                 jira_issue_transition_id: Optional[pulumi.Input[str]] = None,
                 merge_requests_events: Optional[pulumi.Input[bool]] = None,
                 project_key: Optional[pulumi.Input[str]] = None,
                 project_keys: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 use_inherited_settings: Optional[pulumi.Input[bool]] = None,
                 username: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a IntegrationJira resource.
        :param pulumi.Input[str] password: The Jira API token, password, or personal access token to be used with Jira. When your authentication method is basic (jira*auth*type is 0), use an API token for Jira Cloud or a password for Jira Data Center or Jira Server. When your authentication method is a Jira personal access token (jira*auth*type is 1), use the personal access token.
        :param pulumi.Input[str] project: ID of the project you want to activate integration on.
        :param pulumi.Input[str] url: The URL to the JIRA project which is being linked to this GitLab project. For example, https://jira.example.com.
        :param pulumi.Input[str] api_url: The base URL to the Jira instance API. Web URL value is used if not set. For example, https://jira-api.example.com.
        :param pulumi.Input[bool] comment_on_event_enabled: Enable comments inside Jira issues on each GitLab event (commit / merge request)
        :param pulumi.Input[bool] commit_events: Enable notifications for commit events
        :param pulumi.Input[bool] issues_enabled: Enable viewing Jira issues in GitLab.
        :param pulumi.Input[int] jira_auth_type: The authentication method to be used with Jira. 0 means Basic Authentication. 1 means Jira personal access token. Defaults to 0.
        :param pulumi.Input[str] jira_issue_prefix: Prefix to match Jira issue keys.
        :param pulumi.Input[str] jira_issue_regex: Regular expression to match Jira issue keys.
        :param pulumi.Input[str] jira_issue_transition_id: The ID of a transition that moves issues to a closed state. You can find this number under the JIRA workflow administration (Administration > Issues > Workflows) by selecting View under Operations of the desired workflow of your project. By default, this ID is set to 2. *Note**: importing this field is only supported since GitLab 15.2.
        :param pulumi.Input[bool] merge_requests_events: Enable notifications for merge request events
        :param pulumi.Input[str] project_key: The short identifier for your JIRA project, all uppercase, e.g., PROJ.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] project_keys: Keys of Jira projects. When issues_enabled is true, this setting specifies which Jira projects to view issues from in GitLab.
        :param pulumi.Input[bool] use_inherited_settings: Indicates whether or not to inherit default settings. Defaults to false.
        :param pulumi.Input[str] username: The email or username to be used with Jira. For Jira Cloud use an email, for Jira Data Center and Jira Server use a username. Required when using Basic authentication (jira*auth*type is 0).
        """
        pulumi.set(__self__, "password", password)
        pulumi.set(__self__, "project", project)
        pulumi.set(__self__, "url", url)
        if api_url is not None:
            pulumi.set(__self__, "api_url", api_url)
        if comment_on_event_enabled is not None:
            pulumi.set(__self__, "comment_on_event_enabled", comment_on_event_enabled)
        if commit_events is not None:
            pulumi.set(__self__, "commit_events", commit_events)
        if issues_enabled is not None:
            pulumi.set(__self__, "issues_enabled", issues_enabled)
        if jira_auth_type is not None:
            pulumi.set(__self__, "jira_auth_type", jira_auth_type)
        if jira_issue_prefix is not None:
            pulumi.set(__self__, "jira_issue_prefix", jira_issue_prefix)
        if jira_issue_regex is not None:
            pulumi.set(__self__, "jira_issue_regex", jira_issue_regex)
        if jira_issue_transition_automatic is not None:
            pulumi.set(__self__, "jira_issue_transition_automatic", jira_issue_transition_automatic)
        if jira_issue_transition_id is not None:
            pulumi.set(__self__, "jira_issue_transition_id", jira_issue_transition_id)
        if merge_requests_events is not None:
            pulumi.set(__self__, "merge_requests_events", merge_requests_events)
        if project_key is not None:
            pulumi.set(__self__, "project_key", project_key)
        if project_keys is not None:
            pulumi.set(__self__, "project_keys", project_keys)
        if use_inherited_settings is not None:
            pulumi.set(__self__, "use_inherited_settings", use_inherited_settings)
        if username is not None:
            pulumi.set(__self__, "username", username)

    @property
    @pulumi.getter
    def password(self) -> pulumi.Input[str]:
        """
        The Jira API token, password, or personal access token to be used with Jira. When your authentication method is basic (jira*auth*type is 0), use an API token for Jira Cloud or a password for Jira Data Center or Jira Server. When your authentication method is a Jira personal access token (jira*auth*type is 1), use the personal access token.
        """
        return pulumi.get(self, "password")

    @password.setter
    def password(self, value: pulumi.Input[str]):
        pulumi.set(self, "password", value)

    @property
    @pulumi.getter
    def project(self) -> pulumi.Input[str]:
        """
        ID of the project you want to activate integration on.
        """
        return pulumi.get(self, "project")

    @project.setter
    def project(self, value: pulumi.Input[str]):
        pulumi.set(self, "project", value)

    @property
    @pulumi.getter
    def url(self) -> pulumi.Input[str]:
        """
        The URL to the JIRA project which is being linked to this GitLab project. For example, https://jira.example.com.
        """
        return pulumi.get(self, "url")

    @url.setter
    def url(self, value: pulumi.Input[str]):
        pulumi.set(self, "url", value)

    @property
    @pulumi.getter(name="apiUrl")
    def api_url(self) -> Optional[pulumi.Input[str]]:
        """
        The base URL to the Jira instance API. Web URL value is used if not set. For example, https://jira-api.example.com.
        """
        return pulumi.get(self, "api_url")

    @api_url.setter
    def api_url(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "api_url", value)

    @property
    @pulumi.getter(name="commentOnEventEnabled")
    def comment_on_event_enabled(self) -> Optional[pulumi.Input[bool]]:
        """
        Enable comments inside Jira issues on each GitLab event (commit / merge request)
        """
        return pulumi.get(self, "comment_on_event_enabled")

    @comment_on_event_enabled.setter
    def comment_on_event_enabled(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "comment_on_event_enabled", value)

    @property
    @pulumi.getter(name="commitEvents")
    def commit_events(self) -> Optional[pulumi.Input[bool]]:
        """
        Enable notifications for commit events
        """
        return pulumi.get(self, "commit_events")

    @commit_events.setter
    def commit_events(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "commit_events", value)

    @property
    @pulumi.getter(name="issuesEnabled")
    def issues_enabled(self) -> Optional[pulumi.Input[bool]]:
        """
        Enable viewing Jira issues in GitLab.
        """
        return pulumi.get(self, "issues_enabled")

    @issues_enabled.setter
    def issues_enabled(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "issues_enabled", value)

    @property
    @pulumi.getter(name="jiraAuthType")
    def jira_auth_type(self) -> Optional[pulumi.Input[int]]:
        """
        The authentication method to be used with Jira. 0 means Basic Authentication. 1 means Jira personal access token. Defaults to 0.
        """
        return pulumi.get(self, "jira_auth_type")

    @jira_auth_type.setter
    def jira_auth_type(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "jira_auth_type", value)

    @property
    @pulumi.getter(name="jiraIssuePrefix")
    def jira_issue_prefix(self) -> Optional[pulumi.Input[str]]:
        """
        Prefix to match Jira issue keys.
        """
        return pulumi.get(self, "jira_issue_prefix")

    @jira_issue_prefix.setter
    def jira_issue_prefix(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "jira_issue_prefix", value)

    @property
    @pulumi.getter(name="jiraIssueRegex")
    def jira_issue_regex(self) -> Optional[pulumi.Input[str]]:
        """
        Regular expression to match Jira issue keys.
        """
        return pulumi.get(self, "jira_issue_regex")

    @jira_issue_regex.setter
    def jira_issue_regex(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "jira_issue_regex", value)

    @property
    @pulumi.getter(name="jiraIssueTransitionAutomatic")
    def jira_issue_transition_automatic(self) -> Optional[pulumi.Input[bool]]:
        return pulumi.get(self, "jira_issue_transition_automatic")

    @jira_issue_transition_automatic.setter
    def jira_issue_transition_automatic(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "jira_issue_transition_automatic", value)

    @property
    @pulumi.getter(name="jiraIssueTransitionId")
    def jira_issue_transition_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of a transition that moves issues to a closed state. You can find this number under the JIRA workflow administration (Administration > Issues > Workflows) by selecting View under Operations of the desired workflow of your project. By default, this ID is set to 2. *Note**: importing this field is only supported since GitLab 15.2.
        """
        return pulumi.get(self, "jira_issue_transition_id")

    @jira_issue_transition_id.setter
    def jira_issue_transition_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "jira_issue_transition_id", value)

    @property
    @pulumi.getter(name="mergeRequestsEvents")
    def merge_requests_events(self) -> Optional[pulumi.Input[bool]]:
        """
        Enable notifications for merge request events
        """
        return pulumi.get(self, "merge_requests_events")

    @merge_requests_events.setter
    def merge_requests_events(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "merge_requests_events", value)

    @property
    @pulumi.getter(name="projectKey")
    def project_key(self) -> Optional[pulumi.Input[str]]:
        """
        The short identifier for your JIRA project, all uppercase, e.g., PROJ.
        """
        return pulumi.get(self, "project_key")

    @project_key.setter
    def project_key(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "project_key", value)

    @property
    @pulumi.getter(name="projectKeys")
    def project_keys(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        Keys of Jira projects. When issues_enabled is true, this setting specifies which Jira projects to view issues from in GitLab.
        """
        return pulumi.get(self, "project_keys")

    @project_keys.setter
    def project_keys(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "project_keys", value)

    @property
    @pulumi.getter(name="useInheritedSettings")
    def use_inherited_settings(self) -> Optional[pulumi.Input[bool]]:
        """
        Indicates whether or not to inherit default settings. Defaults to false.
        """
        return pulumi.get(self, "use_inherited_settings")

    @use_inherited_settings.setter
    def use_inherited_settings(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "use_inherited_settings", value)

    @property
    @pulumi.getter
    def username(self) -> Optional[pulumi.Input[str]]:
        """
        The email or username to be used with Jira. For Jira Cloud use an email, for Jira Data Center and Jira Server use a username. Required when using Basic authentication (jira*auth*type is 0).
        """
        return pulumi.get(self, "username")

    @username.setter
    def username(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "username", value)


@pulumi.input_type
class _IntegrationJiraState:
    def __init__(__self__, *,
                 active: Optional[pulumi.Input[bool]] = None,
                 api_url: Optional[pulumi.Input[str]] = None,
                 comment_on_event_enabled: Optional[pulumi.Input[bool]] = None,
                 commit_events: Optional[pulumi.Input[bool]] = None,
                 created_at: Optional[pulumi.Input[str]] = None,
                 issues_enabled: Optional[pulumi.Input[bool]] = None,
                 jira_auth_type: Optional[pulumi.Input[int]] = None,
                 jira_issue_prefix: Optional[pulumi.Input[str]] = None,
                 jira_issue_regex: Optional[pulumi.Input[str]] = None,
                 jira_issue_transition_automatic: Optional[pulumi.Input[bool]] = None,
                 jira_issue_transition_id: Optional[pulumi.Input[str]] = None,
                 merge_requests_events: Optional[pulumi.Input[bool]] = None,
                 password: Optional[pulumi.Input[str]] = None,
                 project: Optional[pulumi.Input[str]] = None,
                 project_key: Optional[pulumi.Input[str]] = None,
                 project_keys: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 title: Optional[pulumi.Input[str]] = None,
                 updated_at: Optional[pulumi.Input[str]] = None,
                 url: Optional[pulumi.Input[str]] = None,
                 use_inherited_settings: Optional[pulumi.Input[bool]] = None,
                 username: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering IntegrationJira resources.
        :param pulumi.Input[bool] active: Whether the integration is active.
        :param pulumi.Input[str] api_url: The base URL to the Jira instance API. Web URL value is used if not set. For example, https://jira-api.example.com.
        :param pulumi.Input[bool] comment_on_event_enabled: Enable comments inside Jira issues on each GitLab event (commit / merge request)
        :param pulumi.Input[bool] commit_events: Enable notifications for commit events
        :param pulumi.Input[str] created_at: Create time.
        :param pulumi.Input[bool] issues_enabled: Enable viewing Jira issues in GitLab.
        :param pulumi.Input[int] jira_auth_type: The authentication method to be used with Jira. 0 means Basic Authentication. 1 means Jira personal access token. Defaults to 0.
        :param pulumi.Input[str] jira_issue_prefix: Prefix to match Jira issue keys.
        :param pulumi.Input[str] jira_issue_regex: Regular expression to match Jira issue keys.
        :param pulumi.Input[str] jira_issue_transition_id: The ID of a transition that moves issues to a closed state. You can find this number under the JIRA workflow administration (Administration > Issues > Workflows) by selecting View under Operations of the desired workflow of your project. By default, this ID is set to 2. *Note**: importing this field is only supported since GitLab 15.2.
        :param pulumi.Input[bool] merge_requests_events: Enable notifications for merge request events
        :param pulumi.Input[str] password: The Jira API token, password, or personal access token to be used with Jira. When your authentication method is basic (jira*auth*type is 0), use an API token for Jira Cloud or a password for Jira Data Center or Jira Server. When your authentication method is a Jira personal access token (jira*auth*type is 1), use the personal access token.
        :param pulumi.Input[str] project: ID of the project you want to activate integration on.
        :param pulumi.Input[str] project_key: The short identifier for your JIRA project, all uppercase, e.g., PROJ.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] project_keys: Keys of Jira projects. When issues_enabled is true, this setting specifies which Jira projects to view issues from in GitLab.
        :param pulumi.Input[str] title: Title.
        :param pulumi.Input[str] updated_at: Update time.
        :param pulumi.Input[str] url: The URL to the JIRA project which is being linked to this GitLab project. For example, https://jira.example.com.
        :param pulumi.Input[bool] use_inherited_settings: Indicates whether or not to inherit default settings. Defaults to false.
        :param pulumi.Input[str] username: The email or username to be used with Jira. For Jira Cloud use an email, for Jira Data Center and Jira Server use a username. Required when using Basic authentication (jira*auth*type is 0).
        """
        if active is not None:
            pulumi.set(__self__, "active", active)
        if api_url is not None:
            pulumi.set(__self__, "api_url", api_url)
        if comment_on_event_enabled is not None:
            pulumi.set(__self__, "comment_on_event_enabled", comment_on_event_enabled)
        if commit_events is not None:
            pulumi.set(__self__, "commit_events", commit_events)
        if created_at is not None:
            pulumi.set(__self__, "created_at", created_at)
        if issues_enabled is not None:
            pulumi.set(__self__, "issues_enabled", issues_enabled)
        if jira_auth_type is not None:
            pulumi.set(__self__, "jira_auth_type", jira_auth_type)
        if jira_issue_prefix is not None:
            pulumi.set(__self__, "jira_issue_prefix", jira_issue_prefix)
        if jira_issue_regex is not None:
            pulumi.set(__self__, "jira_issue_regex", jira_issue_regex)
        if jira_issue_transition_automatic is not None:
            pulumi.set(__self__, "jira_issue_transition_automatic", jira_issue_transition_automatic)
        if jira_issue_transition_id is not None:
            pulumi.set(__self__, "jira_issue_transition_id", jira_issue_transition_id)
        if merge_requests_events is not None:
            pulumi.set(__self__, "merge_requests_events", merge_requests_events)
        if password is not None:
            pulumi.set(__self__, "password", password)
        if project is not None:
            pulumi.set(__self__, "project", project)
        if project_key is not None:
            pulumi.set(__self__, "project_key", project_key)
        if project_keys is not None:
            pulumi.set(__self__, "project_keys", project_keys)
        if title is not None:
            pulumi.set(__self__, "title", title)
        if updated_at is not None:
            pulumi.set(__self__, "updated_at", updated_at)
        if url is not None:
            pulumi.set(__self__, "url", url)
        if use_inherited_settings is not None:
            pulumi.set(__self__, "use_inherited_settings", use_inherited_settings)
        if username is not None:
            pulumi.set(__self__, "username", username)

    @property
    @pulumi.getter
    def active(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether the integration is active.
        """
        return pulumi.get(self, "active")

    @active.setter
    def active(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "active", value)

    @property
    @pulumi.getter(name="apiUrl")
    def api_url(self) -> Optional[pulumi.Input[str]]:
        """
        The base URL to the Jira instance API. Web URL value is used if not set. For example, https://jira-api.example.com.
        """
        return pulumi.get(self, "api_url")

    @api_url.setter
    def api_url(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "api_url", value)

    @property
    @pulumi.getter(name="commentOnEventEnabled")
    def comment_on_event_enabled(self) -> Optional[pulumi.Input[bool]]:
        """
        Enable comments inside Jira issues on each GitLab event (commit / merge request)
        """
        return pulumi.get(self, "comment_on_event_enabled")

    @comment_on_event_enabled.setter
    def comment_on_event_enabled(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "comment_on_event_enabled", value)

    @property
    @pulumi.getter(name="commitEvents")
    def commit_events(self) -> Optional[pulumi.Input[bool]]:
        """
        Enable notifications for commit events
        """
        return pulumi.get(self, "commit_events")

    @commit_events.setter
    def commit_events(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "commit_events", value)

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> Optional[pulumi.Input[str]]:
        """
        Create time.
        """
        return pulumi.get(self, "created_at")

    @created_at.setter
    def created_at(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "created_at", value)

    @property
    @pulumi.getter(name="issuesEnabled")
    def issues_enabled(self) -> Optional[pulumi.Input[bool]]:
        """
        Enable viewing Jira issues in GitLab.
        """
        return pulumi.get(self, "issues_enabled")

    @issues_enabled.setter
    def issues_enabled(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "issues_enabled", value)

    @property
    @pulumi.getter(name="jiraAuthType")
    def jira_auth_type(self) -> Optional[pulumi.Input[int]]:
        """
        The authentication method to be used with Jira. 0 means Basic Authentication. 1 means Jira personal access token. Defaults to 0.
        """
        return pulumi.get(self, "jira_auth_type")

    @jira_auth_type.setter
    def jira_auth_type(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "jira_auth_type", value)

    @property
    @pulumi.getter(name="jiraIssuePrefix")
    def jira_issue_prefix(self) -> Optional[pulumi.Input[str]]:
        """
        Prefix to match Jira issue keys.
        """
        return pulumi.get(self, "jira_issue_prefix")

    @jira_issue_prefix.setter
    def jira_issue_prefix(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "jira_issue_prefix", value)

    @property
    @pulumi.getter(name="jiraIssueRegex")
    def jira_issue_regex(self) -> Optional[pulumi.Input[str]]:
        """
        Regular expression to match Jira issue keys.
        """
        return pulumi.get(self, "jira_issue_regex")

    @jira_issue_regex.setter
    def jira_issue_regex(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "jira_issue_regex", value)

    @property
    @pulumi.getter(name="jiraIssueTransitionAutomatic")
    def jira_issue_transition_automatic(self) -> Optional[pulumi.Input[bool]]:
        return pulumi.get(self, "jira_issue_transition_automatic")

    @jira_issue_transition_automatic.setter
    def jira_issue_transition_automatic(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "jira_issue_transition_automatic", value)

    @property
    @pulumi.getter(name="jiraIssueTransitionId")
    def jira_issue_transition_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of a transition that moves issues to a closed state. You can find this number under the JIRA workflow administration (Administration > Issues > Workflows) by selecting View under Operations of the desired workflow of your project. By default, this ID is set to 2. *Note**: importing this field is only supported since GitLab 15.2.
        """
        return pulumi.get(self, "jira_issue_transition_id")

    @jira_issue_transition_id.setter
    def jira_issue_transition_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "jira_issue_transition_id", value)

    @property
    @pulumi.getter(name="mergeRequestsEvents")
    def merge_requests_events(self) -> Optional[pulumi.Input[bool]]:
        """
        Enable notifications for merge request events
        """
        return pulumi.get(self, "merge_requests_events")

    @merge_requests_events.setter
    def merge_requests_events(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "merge_requests_events", value)

    @property
    @pulumi.getter
    def password(self) -> Optional[pulumi.Input[str]]:
        """
        The Jira API token, password, or personal access token to be used with Jira. When your authentication method is basic (jira*auth*type is 0), use an API token for Jira Cloud or a password for Jira Data Center or Jira Server. When your authentication method is a Jira personal access token (jira*auth*type is 1), use the personal access token.
        """
        return pulumi.get(self, "password")

    @password.setter
    def password(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "password", value)

    @property
    @pulumi.getter
    def project(self) -> Optional[pulumi.Input[str]]:
        """
        ID of the project you want to activate integration on.
        """
        return pulumi.get(self, "project")

    @project.setter
    def project(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "project", value)

    @property
    @pulumi.getter(name="projectKey")
    def project_key(self) -> Optional[pulumi.Input[str]]:
        """
        The short identifier for your JIRA project, all uppercase, e.g., PROJ.
        """
        return pulumi.get(self, "project_key")

    @project_key.setter
    def project_key(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "project_key", value)

    @property
    @pulumi.getter(name="projectKeys")
    def project_keys(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        Keys of Jira projects. When issues_enabled is true, this setting specifies which Jira projects to view issues from in GitLab.
        """
        return pulumi.get(self, "project_keys")

    @project_keys.setter
    def project_keys(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "project_keys", value)

    @property
    @pulumi.getter
    def title(self) -> Optional[pulumi.Input[str]]:
        """
        Title.
        """
        return pulumi.get(self, "title")

    @title.setter
    def title(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "title", value)

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> Optional[pulumi.Input[str]]:
        """
        Update time.
        """
        return pulumi.get(self, "updated_at")

    @updated_at.setter
    def updated_at(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "updated_at", value)

    @property
    @pulumi.getter
    def url(self) -> Optional[pulumi.Input[str]]:
        """
        The URL to the JIRA project which is being linked to this GitLab project. For example, https://jira.example.com.
        """
        return pulumi.get(self, "url")

    @url.setter
    def url(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "url", value)

    @property
    @pulumi.getter(name="useInheritedSettings")
    def use_inherited_settings(self) -> Optional[pulumi.Input[bool]]:
        """
        Indicates whether or not to inherit default settings. Defaults to false.
        """
        return pulumi.get(self, "use_inherited_settings")

    @use_inherited_settings.setter
    def use_inherited_settings(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "use_inherited_settings", value)

    @property
    @pulumi.getter
    def username(self) -> Optional[pulumi.Input[str]]:
        """
        The email or username to be used with Jira. For Jira Cloud use an email, for Jira Data Center and Jira Server use a username. Required when using Basic authentication (jira*auth*type is 0).
        """
        return pulumi.get(self, "username")

    @username.setter
    def username(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "username", value)


class IntegrationJira(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 api_url: Optional[pulumi.Input[str]] = None,
                 comment_on_event_enabled: Optional[pulumi.Input[bool]] = None,
                 commit_events: Optional[pulumi.Input[bool]] = None,
                 issues_enabled: Optional[pulumi.Input[bool]] = None,
                 jira_auth_type: Optional[pulumi.Input[int]] = None,
                 jira_issue_prefix: Optional[pulumi.Input[str]] = None,
                 jira_issue_regex: Optional[pulumi.Input[str]] = None,
                 jira_issue_transition_automatic: Optional[pulumi.Input[bool]] = None,
                 jira_issue_transition_id: Optional[pulumi.Input[str]] = None,
                 merge_requests_events: Optional[pulumi.Input[bool]] = None,
                 password: Optional[pulumi.Input[str]] = None,
                 project: Optional[pulumi.Input[str]] = None,
                 project_key: Optional[pulumi.Input[str]] = None,
                 project_keys: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 url: Optional[pulumi.Input[str]] = None,
                 use_inherited_settings: Optional[pulumi.Input[bool]] = None,
                 username: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        The `IntegrationJira` resource allows to manage the lifecycle of a project integration with Jira.

        **Upstream API**: [GitLab REST API docs](https://docs.gitlab.com/ee/api/integrations.html#jira)

        ## Example Usage

        ```python
        import pulumi
        import pulumi_gitlab as gitlab

        awesome_project = gitlab.Project("awesome_project",
            name="awesome_project",
            description="My awesome project.",
            visibility_level="public")
        jira = gitlab.IntegrationJira("jira",
            project=awesome_project.id,
            url="https://jira.example.com",
            username="user",
            password="mypass")
        ```

        ## Import

        Starting in Terraform v1.5.0 you can use an import block to import `gitlab_integration_jira`. For example:

        terraform

        import {

          to = gitlab_integration_jira.example

          id = "see CLI command below for ID"

        }

        Import using the CLI is supported using the following syntax:

        You can import a gitlab_integration_jira state using the project ID, e.g.

        ```sh
        $ pulumi import gitlab:index/integrationJira:IntegrationJira jira 1
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] api_url: The base URL to the Jira instance API. Web URL value is used if not set. For example, https://jira-api.example.com.
        :param pulumi.Input[bool] comment_on_event_enabled: Enable comments inside Jira issues on each GitLab event (commit / merge request)
        :param pulumi.Input[bool] commit_events: Enable notifications for commit events
        :param pulumi.Input[bool] issues_enabled: Enable viewing Jira issues in GitLab.
        :param pulumi.Input[int] jira_auth_type: The authentication method to be used with Jira. 0 means Basic Authentication. 1 means Jira personal access token. Defaults to 0.
        :param pulumi.Input[str] jira_issue_prefix: Prefix to match Jira issue keys.
        :param pulumi.Input[str] jira_issue_regex: Regular expression to match Jira issue keys.
        :param pulumi.Input[str] jira_issue_transition_id: The ID of a transition that moves issues to a closed state. You can find this number under the JIRA workflow administration (Administration > Issues > Workflows) by selecting View under Operations of the desired workflow of your project. By default, this ID is set to 2. *Note**: importing this field is only supported since GitLab 15.2.
        :param pulumi.Input[bool] merge_requests_events: Enable notifications for merge request events
        :param pulumi.Input[str] password: The Jira API token, password, or personal access token to be used with Jira. When your authentication method is basic (jira*auth*type is 0), use an API token for Jira Cloud or a password for Jira Data Center or Jira Server. When your authentication method is a Jira personal access token (jira*auth*type is 1), use the personal access token.
        :param pulumi.Input[str] project: ID of the project you want to activate integration on.
        :param pulumi.Input[str] project_key: The short identifier for your JIRA project, all uppercase, e.g., PROJ.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] project_keys: Keys of Jira projects. When issues_enabled is true, this setting specifies which Jira projects to view issues from in GitLab.
        :param pulumi.Input[str] url: The URL to the JIRA project which is being linked to this GitLab project. For example, https://jira.example.com.
        :param pulumi.Input[bool] use_inherited_settings: Indicates whether or not to inherit default settings. Defaults to false.
        :param pulumi.Input[str] username: The email or username to be used with Jira. For Jira Cloud use an email, for Jira Data Center and Jira Server use a username. Required when using Basic authentication (jira*auth*type is 0).
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: IntegrationJiraArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        The `IntegrationJira` resource allows to manage the lifecycle of a project integration with Jira.

        **Upstream API**: [GitLab REST API docs](https://docs.gitlab.com/ee/api/integrations.html#jira)

        ## Example Usage

        ```python
        import pulumi
        import pulumi_gitlab as gitlab

        awesome_project = gitlab.Project("awesome_project",
            name="awesome_project",
            description="My awesome project.",
            visibility_level="public")
        jira = gitlab.IntegrationJira("jira",
            project=awesome_project.id,
            url="https://jira.example.com",
            username="user",
            password="mypass")
        ```

        ## Import

        Starting in Terraform v1.5.0 you can use an import block to import `gitlab_integration_jira`. For example:

        terraform

        import {

          to = gitlab_integration_jira.example

          id = "see CLI command below for ID"

        }

        Import using the CLI is supported using the following syntax:

        You can import a gitlab_integration_jira state using the project ID, e.g.

        ```sh
        $ pulumi import gitlab:index/integrationJira:IntegrationJira jira 1
        ```

        :param str resource_name: The name of the resource.
        :param IntegrationJiraArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(IntegrationJiraArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 api_url: Optional[pulumi.Input[str]] = None,
                 comment_on_event_enabled: Optional[pulumi.Input[bool]] = None,
                 commit_events: Optional[pulumi.Input[bool]] = None,
                 issues_enabled: Optional[pulumi.Input[bool]] = None,
                 jira_auth_type: Optional[pulumi.Input[int]] = None,
                 jira_issue_prefix: Optional[pulumi.Input[str]] = None,
                 jira_issue_regex: Optional[pulumi.Input[str]] = None,
                 jira_issue_transition_automatic: Optional[pulumi.Input[bool]] = None,
                 jira_issue_transition_id: Optional[pulumi.Input[str]] = None,
                 merge_requests_events: Optional[pulumi.Input[bool]] = None,
                 password: Optional[pulumi.Input[str]] = None,
                 project: Optional[pulumi.Input[str]] = None,
                 project_key: Optional[pulumi.Input[str]] = None,
                 project_keys: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 url: Optional[pulumi.Input[str]] = None,
                 use_inherited_settings: Optional[pulumi.Input[bool]] = None,
                 username: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = IntegrationJiraArgs.__new__(IntegrationJiraArgs)

            __props__.__dict__["api_url"] = api_url
            __props__.__dict__["comment_on_event_enabled"] = comment_on_event_enabled
            __props__.__dict__["commit_events"] = commit_events
            __props__.__dict__["issues_enabled"] = issues_enabled
            __props__.__dict__["jira_auth_type"] = jira_auth_type
            __props__.__dict__["jira_issue_prefix"] = jira_issue_prefix
            __props__.__dict__["jira_issue_regex"] = jira_issue_regex
            __props__.__dict__["jira_issue_transition_automatic"] = jira_issue_transition_automatic
            __props__.__dict__["jira_issue_transition_id"] = jira_issue_transition_id
            __props__.__dict__["merge_requests_events"] = merge_requests_events
            if password is None and not opts.urn:
                raise TypeError("Missing required property 'password'")
            __props__.__dict__["password"] = None if password is None else pulumi.Output.secret(password)
            if project is None and not opts.urn:
                raise TypeError("Missing required property 'project'")
            __props__.__dict__["project"] = project
            __props__.__dict__["project_key"] = project_key
            __props__.__dict__["project_keys"] = project_keys
            if url is None and not opts.urn:
                raise TypeError("Missing required property 'url'")
            __props__.__dict__["url"] = url
            __props__.__dict__["use_inherited_settings"] = use_inherited_settings
            __props__.__dict__["username"] = username
            __props__.__dict__["active"] = None
            __props__.__dict__["created_at"] = None
            __props__.__dict__["title"] = None
            __props__.__dict__["updated_at"] = None
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["password"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(IntegrationJira, __self__).__init__(
            'gitlab:index/integrationJira:IntegrationJira',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            active: Optional[pulumi.Input[bool]] = None,
            api_url: Optional[pulumi.Input[str]] = None,
            comment_on_event_enabled: Optional[pulumi.Input[bool]] = None,
            commit_events: Optional[pulumi.Input[bool]] = None,
            created_at: Optional[pulumi.Input[str]] = None,
            issues_enabled: Optional[pulumi.Input[bool]] = None,
            jira_auth_type: Optional[pulumi.Input[int]] = None,
            jira_issue_prefix: Optional[pulumi.Input[str]] = None,
            jira_issue_regex: Optional[pulumi.Input[str]] = None,
            jira_issue_transition_automatic: Optional[pulumi.Input[bool]] = None,
            jira_issue_transition_id: Optional[pulumi.Input[str]] = None,
            merge_requests_events: Optional[pulumi.Input[bool]] = None,
            password: Optional[pulumi.Input[str]] = None,
            project: Optional[pulumi.Input[str]] = None,
            project_key: Optional[pulumi.Input[str]] = None,
            project_keys: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            title: Optional[pulumi.Input[str]] = None,
            updated_at: Optional[pulumi.Input[str]] = None,
            url: Optional[pulumi.Input[str]] = None,
            use_inherited_settings: Optional[pulumi.Input[bool]] = None,
            username: Optional[pulumi.Input[str]] = None) -> 'IntegrationJira':
        """
        Get an existing IntegrationJira resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[bool] active: Whether the integration is active.
        :param pulumi.Input[str] api_url: The base URL to the Jira instance API. Web URL value is used if not set. For example, https://jira-api.example.com.
        :param pulumi.Input[bool] comment_on_event_enabled: Enable comments inside Jira issues on each GitLab event (commit / merge request)
        :param pulumi.Input[bool] commit_events: Enable notifications for commit events
        :param pulumi.Input[str] created_at: Create time.
        :param pulumi.Input[bool] issues_enabled: Enable viewing Jira issues in GitLab.
        :param pulumi.Input[int] jira_auth_type: The authentication method to be used with Jira. 0 means Basic Authentication. 1 means Jira personal access token. Defaults to 0.
        :param pulumi.Input[str] jira_issue_prefix: Prefix to match Jira issue keys.
        :param pulumi.Input[str] jira_issue_regex: Regular expression to match Jira issue keys.
        :param pulumi.Input[str] jira_issue_transition_id: The ID of a transition that moves issues to a closed state. You can find this number under the JIRA workflow administration (Administration > Issues > Workflows) by selecting View under Operations of the desired workflow of your project. By default, this ID is set to 2. *Note**: importing this field is only supported since GitLab 15.2.
        :param pulumi.Input[bool] merge_requests_events: Enable notifications for merge request events
        :param pulumi.Input[str] password: The Jira API token, password, or personal access token to be used with Jira. When your authentication method is basic (jira*auth*type is 0), use an API token for Jira Cloud or a password for Jira Data Center or Jira Server. When your authentication method is a Jira personal access token (jira*auth*type is 1), use the personal access token.
        :param pulumi.Input[str] project: ID of the project you want to activate integration on.
        :param pulumi.Input[str] project_key: The short identifier for your JIRA project, all uppercase, e.g., PROJ.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] project_keys: Keys of Jira projects. When issues_enabled is true, this setting specifies which Jira projects to view issues from in GitLab.
        :param pulumi.Input[str] title: Title.
        :param pulumi.Input[str] updated_at: Update time.
        :param pulumi.Input[str] url: The URL to the JIRA project which is being linked to this GitLab project. For example, https://jira.example.com.
        :param pulumi.Input[bool] use_inherited_settings: Indicates whether or not to inherit default settings. Defaults to false.
        :param pulumi.Input[str] username: The email or username to be used with Jira. For Jira Cloud use an email, for Jira Data Center and Jira Server use a username. Required when using Basic authentication (jira*auth*type is 0).
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _IntegrationJiraState.__new__(_IntegrationJiraState)

        __props__.__dict__["active"] = active
        __props__.__dict__["api_url"] = api_url
        __props__.__dict__["comment_on_event_enabled"] = comment_on_event_enabled
        __props__.__dict__["commit_events"] = commit_events
        __props__.__dict__["created_at"] = created_at
        __props__.__dict__["issues_enabled"] = issues_enabled
        __props__.__dict__["jira_auth_type"] = jira_auth_type
        __props__.__dict__["jira_issue_prefix"] = jira_issue_prefix
        __props__.__dict__["jira_issue_regex"] = jira_issue_regex
        __props__.__dict__["jira_issue_transition_automatic"] = jira_issue_transition_automatic
        __props__.__dict__["jira_issue_transition_id"] = jira_issue_transition_id
        __props__.__dict__["merge_requests_events"] = merge_requests_events
        __props__.__dict__["password"] = password
        __props__.__dict__["project"] = project
        __props__.__dict__["project_key"] = project_key
        __props__.__dict__["project_keys"] = project_keys
        __props__.__dict__["title"] = title
        __props__.__dict__["updated_at"] = updated_at
        __props__.__dict__["url"] = url
        __props__.__dict__["use_inherited_settings"] = use_inherited_settings
        __props__.__dict__["username"] = username
        return IntegrationJira(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def active(self) -> pulumi.Output[bool]:
        """
        Whether the integration is active.
        """
        return pulumi.get(self, "active")

    @property
    @pulumi.getter(name="apiUrl")
    def api_url(self) -> pulumi.Output[str]:
        """
        The base URL to the Jira instance API. Web URL value is used if not set. For example, https://jira-api.example.com.
        """
        return pulumi.get(self, "api_url")

    @property
    @pulumi.getter(name="commentOnEventEnabled")
    def comment_on_event_enabled(self) -> pulumi.Output[Optional[bool]]:
        """
        Enable comments inside Jira issues on each GitLab event (commit / merge request)
        """
        return pulumi.get(self, "comment_on_event_enabled")

    @property
    @pulumi.getter(name="commitEvents")
    def commit_events(self) -> pulumi.Output[bool]:
        """
        Enable notifications for commit events
        """
        return pulumi.get(self, "commit_events")

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> pulumi.Output[str]:
        """
        Create time.
        """
        return pulumi.get(self, "created_at")

    @property
    @pulumi.getter(name="issuesEnabled")
    def issues_enabled(self) -> pulumi.Output[Optional[bool]]:
        """
        Enable viewing Jira issues in GitLab.
        """
        return pulumi.get(self, "issues_enabled")

    @property
    @pulumi.getter(name="jiraAuthType")
    def jira_auth_type(self) -> pulumi.Output[Optional[int]]:
        """
        The authentication method to be used with Jira. 0 means Basic Authentication. 1 means Jira personal access token. Defaults to 0.
        """
        return pulumi.get(self, "jira_auth_type")

    @property
    @pulumi.getter(name="jiraIssuePrefix")
    def jira_issue_prefix(self) -> pulumi.Output[Optional[str]]:
        """
        Prefix to match Jira issue keys.
        """
        return pulumi.get(self, "jira_issue_prefix")

    @property
    @pulumi.getter(name="jiraIssueRegex")
    def jira_issue_regex(self) -> pulumi.Output[Optional[str]]:
        """
        Regular expression to match Jira issue keys.
        """
        return pulumi.get(self, "jira_issue_regex")

    @property
    @pulumi.getter(name="jiraIssueTransitionAutomatic")
    def jira_issue_transition_automatic(self) -> pulumi.Output[Optional[bool]]:
        return pulumi.get(self, "jira_issue_transition_automatic")

    @property
    @pulumi.getter(name="jiraIssueTransitionId")
    def jira_issue_transition_id(self) -> pulumi.Output[Optional[str]]:
        """
        The ID of a transition that moves issues to a closed state. You can find this number under the JIRA workflow administration (Administration > Issues > Workflows) by selecting View under Operations of the desired workflow of your project. By default, this ID is set to 2. *Note**: importing this field is only supported since GitLab 15.2.
        """
        return pulumi.get(self, "jira_issue_transition_id")

    @property
    @pulumi.getter(name="mergeRequestsEvents")
    def merge_requests_events(self) -> pulumi.Output[bool]:
        """
        Enable notifications for merge request events
        """
        return pulumi.get(self, "merge_requests_events")

    @property
    @pulumi.getter
    def password(self) -> pulumi.Output[str]:
        """
        The Jira API token, password, or personal access token to be used with Jira. When your authentication method is basic (jira*auth*type is 0), use an API token for Jira Cloud or a password for Jira Data Center or Jira Server. When your authentication method is a Jira personal access token (jira*auth*type is 1), use the personal access token.
        """
        return pulumi.get(self, "password")

    @property
    @pulumi.getter
    def project(self) -> pulumi.Output[str]:
        """
        ID of the project you want to activate integration on.
        """
        return pulumi.get(self, "project")

    @property
    @pulumi.getter(name="projectKey")
    def project_key(self) -> pulumi.Output[Optional[str]]:
        """
        The short identifier for your JIRA project, all uppercase, e.g., PROJ.
        """
        return pulumi.get(self, "project_key")

    @property
    @pulumi.getter(name="projectKeys")
    def project_keys(self) -> pulumi.Output[Optional[Sequence[str]]]:
        """
        Keys of Jira projects. When issues_enabled is true, this setting specifies which Jira projects to view issues from in GitLab.
        """
        return pulumi.get(self, "project_keys")

    @property
    @pulumi.getter
    def title(self) -> pulumi.Output[str]:
        """
        Title.
        """
        return pulumi.get(self, "title")

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> pulumi.Output[str]:
        """
        Update time.
        """
        return pulumi.get(self, "updated_at")

    @property
    @pulumi.getter
    def url(self) -> pulumi.Output[str]:
        """
        The URL to the JIRA project which is being linked to this GitLab project. For example, https://jira.example.com.
        """
        return pulumi.get(self, "url")

    @property
    @pulumi.getter(name="useInheritedSettings")
    def use_inherited_settings(self) -> pulumi.Output[Optional[bool]]:
        """
        Indicates whether or not to inherit default settings. Defaults to false.
        """
        return pulumi.get(self, "use_inherited_settings")

    @property
    @pulumi.getter
    def username(self) -> pulumi.Output[Optional[str]]:
        """
        The email or username to be used with Jira. For Jira Cloud use an email, for Jira Data Center and Jira Server use a username. Required when using Basic authentication (jira*auth*type is 0).
        """
        return pulumi.get(self, "username")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['ValueStreamAnalyticsArgs', 'ValueStreamAnalytics']

@pulumi.input_type
class ValueStreamAnalyticsArgs:
    def __init__(__self__, *,
                 stages: pulumi.Input[Sequence[pulumi.Input['ValueStreamAnalyticsStageArgs']]],
                 group_full_path: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 project_full_path: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a ValueStreamAnalytics resource.
        :param pulumi.Input[Sequence[pulumi.Input['ValueStreamAnalyticsStageArgs']]] stages: Stages of the value stream
        :param pulumi.Input[str] group_full_path: Full path of the group the value stream is created in. **One of `group_full_path` OR `project_full_path` is required.**
        :param pulumi.Input[str] name: The name of the value stream
        :param pulumi.Input[str] project_full_path: Full path of the project the value stream is created in. **One of `group_full_path` OR `project_full_path` is required.**
        """
        pulumi.set(__self__, "stages", stages)
        if group_full_path is not None:
            pulumi.set(__self__, "group_full_path", group_full_path)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if project_full_path is not None:
            pulumi.set(__self__, "project_full_path", project_full_path)

    @property
    @pulumi.getter
    def stages(self) -> pulumi.Input[Sequence[pulumi.Input['ValueStreamAnalyticsStageArgs']]]:
        """
        Stages of the value stream
        """
        return pulumi.get(self, "stages")

    @stages.setter
    def stages(self, value: pulumi.Input[Sequence[pulumi.Input['ValueStreamAnalyticsStageArgs']]]):
        pulumi.set(self, "stages", value)

    @property
    @pulumi.getter(name="groupFullPath")
    def group_full_path(self) -> Optional[pulumi.Input[str]]:
        """
        Full path of the group the value stream is created in. **One of `group_full_path` OR `project_full_path` is required.**
        """
        return pulumi.get(self, "group_full_path")

    @group_full_path.setter
    def group_full_path(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "group_full_path", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the value stream
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="projectFullPath")
    def project_full_path(self) -> Optional[pulumi.Input[str]]:
        """
        Full path of the project the value stream is created in. **One of `group_full_path` OR `project_full_path` is required.**
        """
        return pulumi.get(self, "project_full_path")

    @project_full_path.setter
    def project_full_path(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "project_full_path", value)


@pulumi.input_type
class _ValueStreamAnalyticsState:
    def __init__(__self__, *,
                 group_full_path: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 project_full_path: Optional[pulumi.Input[str]] = None,
                 stages: Optional[pulumi.Input[Sequence[pulumi.Input['ValueStreamAnalyticsStageArgs']]]] = None):
        """
        Input properties used for looking up and filtering ValueStreamAnalytics resources.
        :param pulumi.Input[str] group_full_path: Full path of the group the value stream is created in. **One of `group_full_path` OR `project_full_path` is required.**
        :param pulumi.Input[str] name: The name of the value stream
        :param pulumi.Input[str] project_full_path: Full path of the project the value stream is created in. **One of `group_full_path` OR `project_full_path` is required.**
        :param pulumi.Input[Sequence[pulumi.Input['ValueStreamAnalyticsStageArgs']]] stages: Stages of the value stream
        """
        if group_full_path is not None:
            pulumi.set(__self__, "group_full_path", group_full_path)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if project_full_path is not None:
            pulumi.set(__self__, "project_full_path", project_full_path)
        if stages is not None:
            pulumi.set(__self__, "stages", stages)

    @property
    @pulumi.getter(name="groupFullPath")
    def group_full_path(self) -> Optional[pulumi.Input[str]]:
        """
        Full path of the group the value stream is created in. **One of `group_full_path` OR `project_full_path` is required.**
        """
        return pulumi.get(self, "group_full_path")

    @group_full_path.setter
    def group_full_path(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "group_full_path", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the value stream
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="projectFullPath")
    def project_full_path(self) -> Optional[pulumi.Input[str]]:
        """
        Full path of the project the value stream is created in. **One of `group_full_path` OR `project_full_path` is required.**
        """
        return pulumi.get(self, "project_full_path")

    @project_full_path.setter
    def project_full_path(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "project_full_path", value)

    @property
    @pulumi.getter
    def stages(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ValueStreamAnalyticsStageArgs']]]]:
        """
        Stages of the value stream
        """
        return pulumi.get(self, "stages")

    @stages.setter
    def stages(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ValueStreamAnalyticsStageArgs']]]]):
        pulumi.set(self, "stages", value)


class ValueStreamAnalytics(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 group_full_path: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 project_full_path: Optional[pulumi.Input[str]] = None,
                 stages: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ValueStreamAnalyticsStageArgs', 'ValueStreamAnalyticsStageArgsDict']]]]] = None,
                 __props__=None):
        """
        The `ValueStreamAnalytics` resource allows to manage the lifecycle of value stream analytics.

        > This resource requires a GitLab Enterprise instance with a Premium license to create custom value stream analytics.

        **Upstream API**: [GitLab GraphQL API docs](https://docs.gitlab.com/ee/api/graphql/reference/#mutationvaluestreamcreate)

        ## Import

        Starting in Terraform v1.5.0 you can use an import block to import `gitlab_value_stream_analytics`. For example:

        terraform

        import {

          to = gitlab_value_stream_analytics.example

          id = "see CLI command below for ID"

        }

        Import using the CLI is supported using the following syntax:

        Gitlab value stream analytics can be imported with a key composed of `<full_path_type>:<full_path>:<value_stream_id>`, e.g.

        ```sh
        $ pulumi import gitlab:index/valueStreamAnalytics:ValueStreamAnalytics group "group:people/engineers:42"
        ```

        ```sh
        $ pulumi import gitlab:index/valueStreamAnalytics:ValueStreamAnalytics project "project:projects/sample:43"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] group_full_path: Full path of the group the value stream is created in. **One of `group_full_path` OR `project_full_path` is required.**
        :param pulumi.Input[str] name: The name of the value stream
        :param pulumi.Input[str] project_full_path: Full path of the project the value stream is created in. **One of `group_full_path` OR `project_full_path` is required.**
        :param pulumi.Input[Sequence[pulumi.Input[Union['ValueStreamAnalyticsStageArgs', 'ValueStreamAnalyticsStageArgsDict']]]] stages: Stages of the value stream
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ValueStreamAnalyticsArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        The `ValueStreamAnalytics` resource allows to manage the lifecycle of value stream analytics.

        > This resource requires a GitLab Enterprise instance with a Premium license to create custom value stream analytics.

        **Upstream API**: [GitLab GraphQL API docs](https://docs.gitlab.com/ee/api/graphql/reference/#mutationvaluestreamcreate)

        ## Import

        Starting in Terraform v1.5.0 you can use an import block to import `gitlab_value_stream_analytics`. For example:

        terraform

        import {

          to = gitlab_value_stream_analytics.example

          id = "see CLI command below for ID"

        }

        Import using the CLI is supported using the following syntax:

        Gitlab value stream analytics can be imported with a key composed of `<full_path_type>:<full_path>:<value_stream_id>`, e.g.

        ```sh
        $ pulumi import gitlab:index/valueStreamAnalytics:ValueStreamAnalytics group "group:people/engineers:42"
        ```

        ```sh
        $ pulumi import gitlab:index/valueStreamAnalytics:ValueStreamAnalytics project "project:projects/sample:43"
        ```

        :param str resource_name: The name of the resource.
        :param ValueStreamAnalyticsArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ValueStreamAnalyticsArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 group_full_path: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 project_full_path: Optional[pulumi.Input[str]] = None,
                 stages: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ValueStreamAnalyticsStageArgs', 'ValueStreamAnalyticsStageArgsDict']]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ValueStreamAnalyticsArgs.__new__(ValueStreamAnalyticsArgs)

            __props__.__dict__["group_full_path"] = group_full_path
            __props__.__dict__["name"] = name
            __props__.__dict__["project_full_path"] = project_full_path
            if stages is None and not opts.urn:
                raise TypeError("Missing required property 'stages'")
            __props__.__dict__["stages"] = stages
        super(ValueStreamAnalytics, __self__).__init__(
            'gitlab:index/valueStreamAnalytics:ValueStreamAnalytics',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            group_full_path: Optional[pulumi.Input[str]] = None,
            name: Optional[pulumi.Input[str]] = None,
            project_full_path: Optional[pulumi.Input[str]] = None,
            stages: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ValueStreamAnalyticsStageArgs', 'ValueStreamAnalyticsStageArgsDict']]]]] = None) -> 'ValueStreamAnalytics':
        """
        Get an existing ValueStreamAnalytics resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] group_full_path: Full path of the group the value stream is created in. **One of `group_full_path` OR `project_full_path` is required.**
        :param pulumi.Input[str] name: The name of the value stream
        :param pulumi.Input[str] project_full_path: Full path of the project the value stream is created in. **One of `group_full_path` OR `project_full_path` is required.**
        :param pulumi.Input[Sequence[pulumi.Input[Union['ValueStreamAnalyticsStageArgs', 'ValueStreamAnalyticsStageArgsDict']]]] stages: Stages of the value stream
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ValueStreamAnalyticsState.__new__(_ValueStreamAnalyticsState)

        __props__.__dict__["group_full_path"] = group_full_path
        __props__.__dict__["name"] = name
        __props__.__dict__["project_full_path"] = project_full_path
        __props__.__dict__["stages"] = stages
        return ValueStreamAnalytics(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="groupFullPath")
    def group_full_path(self) -> pulumi.Output[Optional[str]]:
        """
        Full path of the group the value stream is created in. **One of `group_full_path` OR `project_full_path` is required.**
        """
        return pulumi.get(self, "group_full_path")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        The name of the value stream
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="projectFullPath")
    def project_full_path(self) -> pulumi.Output[Optional[str]]:
        """
        Full path of the project the value stream is created in. **One of `group_full_path` OR `project_full_path` is required.**
        """
        return pulumi.get(self, "project_full_path")

    @property
    @pulumi.getter
    def stages(self) -> pulumi.Output[Sequence['outputs.ValueStreamAnalyticsStage']]:
        """
        Stages of the value stream
        """
        return pulumi.get(self, "stages")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = [
    'GetProjectMilestoneResult',
    'AwaitableGetProjectMilestoneResult',
    'get_project_milestone',
    'get_project_milestone_output',
]

@pulumi.output_type
class GetProjectMilestoneResult:
    """
    A collection of values returned by getProjectMilestone.
    """
    def __init__(__self__, created_at=None, description=None, due_date=None, expired=None, id=None, iid=None, milestone_id=None, project=None, project_id=None, start_date=None, state=None, title=None, updated_at=None, web_url=None):
        if created_at and not isinstance(created_at, str):
            raise TypeError("Expected argument 'created_at' to be a str")
        pulumi.set(__self__, "created_at", created_at)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if due_date and not isinstance(due_date, str):
            raise TypeError("Expected argument 'due_date' to be a str")
        pulumi.set(__self__, "due_date", due_date)
        if expired and not isinstance(expired, bool):
            raise TypeError("Expected argument 'expired' to be a bool")
        pulumi.set(__self__, "expired", expired)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if iid and not isinstance(iid, int):
            raise TypeError("Expected argument 'iid' to be a int")
        pulumi.set(__self__, "iid", iid)
        if milestone_id and not isinstance(milestone_id, int):
            raise TypeError("Expected argument 'milestone_id' to be a int")
        pulumi.set(__self__, "milestone_id", milestone_id)
        if project and not isinstance(project, str):
            raise TypeError("Expected argument 'project' to be a str")
        pulumi.set(__self__, "project", project)
        if project_id and not isinstance(project_id, int):
            raise TypeError("Expected argument 'project_id' to be a int")
        pulumi.set(__self__, "project_id", project_id)
        if start_date and not isinstance(start_date, str):
            raise TypeError("Expected argument 'start_date' to be a str")
        pulumi.set(__self__, "start_date", start_date)
        if state and not isinstance(state, str):
            raise TypeError("Expected argument 'state' to be a str")
        pulumi.set(__self__, "state", state)
        if title and not isinstance(title, str):
            raise TypeError("Expected argument 'title' to be a str")
        pulumi.set(__self__, "title", title)
        if updated_at and not isinstance(updated_at, str):
            raise TypeError("Expected argument 'updated_at' to be a str")
        pulumi.set(__self__, "updated_at", updated_at)
        if web_url and not isinstance(web_url, str):
            raise TypeError("Expected argument 'web_url' to be a str")
        pulumi.set(__self__, "web_url", web_url)

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> str:
        """
        The time of creation of the milestone. Date time string, ISO 8601 formatted, for example 2016-03-11T03:45:40Z.
        """
        return pulumi.get(self, "created_at")

    @property
    @pulumi.getter
    def description(self) -> str:
        """
        The description of the milestone.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="dueDate")
    def due_date(self) -> str:
        """
        The due date of the milestone. Date time string in the format YYYY-MM-DD, for example 2016-03-11.
        """
        return pulumi.get(self, "due_date")

    @property
    @pulumi.getter
    def expired(self) -> bool:
        """
        Bool, true if milestone expired.
        """
        return pulumi.get(self, "expired")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def iid(self) -> int:
        """
        The ID of the project's milestone.
        """
        return pulumi.get(self, "iid")

    @property
    @pulumi.getter(name="milestoneId")
    def milestone_id(self) -> int:
        """
        The instance-wide ID of the project’s milestone.
        """
        return pulumi.get(self, "milestone_id")

    @property
    @pulumi.getter
    def project(self) -> str:
        """
        The ID or URL-encoded path of the project owned by the authenticated user.
        """
        return pulumi.get(self, "project")

    @property
    @pulumi.getter(name="projectId")
    def project_id(self) -> int:
        """
        The project ID of milestone.
        """
        return pulumi.get(self, "project_id")

    @property
    @pulumi.getter(name="startDate")
    def start_date(self) -> str:
        """
        The start date of the milestone. Date time string in the format YYYY-MM-DD, for example 2016-03-11.
        """
        return pulumi.get(self, "start_date")

    @property
    @pulumi.getter
    def state(self) -> str:
        """
        The state of the milestone. Valid values are: `active`, `closed`.
        """
        return pulumi.get(self, "state")

    @property
    @pulumi.getter
    def title(self) -> str:
        """
        The title of a milestone.
        """
        return pulumi.get(self, "title")

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> str:
        """
        The last update time of the milestone. Date time string, ISO 8601 formatted, for example 2016-03-11T03:45:40Z.
        """
        return pulumi.get(self, "updated_at")

    @property
    @pulumi.getter(name="webUrl")
    def web_url(self) -> str:
        """
        The web URL of the milestone.
        """
        return pulumi.get(self, "web_url")


class AwaitableGetProjectMilestoneResult(GetProjectMilestoneResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetProjectMilestoneResult(
            created_at=self.created_at,
            description=self.description,
            due_date=self.due_date,
            expired=self.expired,
            id=self.id,
            iid=self.iid,
            milestone_id=self.milestone_id,
            project=self.project,
            project_id=self.project_id,
            start_date=self.start_date,
            state=self.state,
            title=self.title,
            updated_at=self.updated_at,
            web_url=self.web_url)


def get_project_milestone(milestone_id: Optional[int] = None,
                          project: Optional[str] = None,
                          opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetProjectMilestoneResult:
    """
    The `ProjectMilestone` data source allows get details of a project milestone.

    **Upstream API**: [GitLab REST API docs](https://docs.gitlab.com/ee/api/milestones.html)


    :param int milestone_id: The instance-wide ID of the project’s milestone.
    :param str project: The ID or URL-encoded path of the project owned by the authenticated user.
    """
    __args__ = dict()
    __args__['milestoneId'] = milestone_id
    __args__['project'] = project
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('gitlab:index/getProjectMilestone:getProjectMilestone', __args__, opts=opts, typ=GetProjectMilestoneResult).value

    return AwaitableGetProjectMilestoneResult(
        created_at=pulumi.get(__ret__, 'created_at'),
        description=pulumi.get(__ret__, 'description'),
        due_date=pulumi.get(__ret__, 'due_date'),
        expired=pulumi.get(__ret__, 'expired'),
        id=pulumi.get(__ret__, 'id'),
        iid=pulumi.get(__ret__, 'iid'),
        milestone_id=pulumi.get(__ret__, 'milestone_id'),
        project=pulumi.get(__ret__, 'project'),
        project_id=pulumi.get(__ret__, 'project_id'),
        start_date=pulumi.get(__ret__, 'start_date'),
        state=pulumi.get(__ret__, 'state'),
        title=pulumi.get(__ret__, 'title'),
        updated_at=pulumi.get(__ret__, 'updated_at'),
        web_url=pulumi.get(__ret__, 'web_url'))
def get_project_milestone_output(milestone_id: Optional[pulumi.Input[int]] = None,
                                 project: Optional[pulumi.Input[str]] = None,
                                 opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetProjectMilestoneResult]:
    """
    The `ProjectMilestone` data source allows get details of a project milestone.

    **Upstream API**: [GitLab REST API docs](https://docs.gitlab.com/ee/api/milestones.html)


    :param int milestone_id: The instance-wide ID of the project’s milestone.
    :param str project: The ID or URL-encoded path of the project owned by the authenticated user.
    """
    __args__ = dict()
    __args__['milestoneId'] = milestone_id
    __args__['project'] = project
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('gitlab:index/getProjectMilestone:getProjectMilestone', __args__, opts=opts, typ=GetProjectMilestoneResult)
    return __ret__.apply(lambda __response__: GetProjectMilestoneResult(
        created_at=pulumi.get(__response__, 'created_at'),
        description=pulumi.get(__response__, 'description'),
        due_date=pulumi.get(__response__, 'due_date'),
        expired=pulumi.get(__response__, 'expired'),
        id=pulumi.get(__response__, 'id'),
        iid=pulumi.get(__response__, 'iid'),
        milestone_id=pulumi.get(__response__, 'milestone_id'),
        project=pulumi.get(__response__, 'project'),
        project_id=pulumi.get(__response__, 'project_id'),
        start_date=pulumi.get(__response__, 'start_date'),
        state=pulumi.get(__response__, 'state'),
        title=pulumi.get(__response__, 'title'),
        updated_at=pulumi.get(__response__, 'updated_at'),
        web_url=pulumi.get(__response__, 'web_url')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs

__all__ = [
    'GetProjectProtectedTagsResult',
    'AwaitableGetProjectProtectedTagsResult',
    'get_project_protected_tags',
    'get_project_protected_tags_output',
]

@pulumi.output_type
class GetProjectProtectedTagsResult:
    """
    A collection of values returned by getProjectProtectedTags.
    """
    def __init__(__self__, id=None, project=None, protected_tags=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if project and not isinstance(project, str):
            raise TypeError("Expected argument 'project' to be a str")
        pulumi.set(__self__, "project", project)
        if protected_tags and not isinstance(protected_tags, list):
            raise TypeError("Expected argument 'protected_tags' to be a list")
        pulumi.set(__self__, "protected_tags", protected_tags)

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The ID of this resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def project(self) -> str:
        """
        The integer or path with namespace that uniquely identifies the project.
        """
        return pulumi.get(self, "project")

    @property
    @pulumi.getter(name="protectedTags")
    def protected_tags(self) -> Sequence['outputs.GetProjectProtectedTagsProtectedTagResult']:
        """
        A list of protected tags, as defined below.
        """
        return pulumi.get(self, "protected_tags")


class AwaitableGetProjectProtectedTagsResult(GetProjectProtectedTagsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetProjectProtectedTagsResult(
            id=self.id,
            project=self.project,
            protected_tags=self.protected_tags)


def get_project_protected_tags(project: Optional[str] = None,
                               opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetProjectProtectedTagsResult:
    """
    The `get_project_protected_tags` data source allows details of the protected tags of a given project.

    **Upstream API**: [GitLab REST API docs](https://docs.gitlab.com/ee/api/protected_tags.html#list-protected-tags)


    :param str project: The integer or path with namespace that uniquely identifies the project.
    """
    __args__ = dict()
    __args__['project'] = project
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('gitlab:index/getProjectProtectedTags:getProjectProtectedTags', __args__, opts=opts, typ=GetProjectProtectedTagsResult).value

    return AwaitableGetProjectProtectedTagsResult(
        id=pulumi.get(__ret__, 'id'),
        project=pulumi.get(__ret__, 'project'),
        protected_tags=pulumi.get(__ret__, 'protected_tags'))
def get_project_protected_tags_output(project: Optional[pulumi.Input[str]] = None,
                                      opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetProjectProtectedTagsResult]:
    """
    The `get_project_protected_tags` data source allows details of the protected tags of a given project.

    **Upstream API**: [GitLab REST API docs](https://docs.gitlab.com/ee/api/protected_tags.html#list-protected-tags)


    :param str project: The integer or path with namespace that uniquely identifies the project.
    """
    __args__ = dict()
    __args__['project'] = project
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('gitlab:index/getProjectProtectedTags:getProjectProtectedTags', __args__, opts=opts, typ=GetProjectProtectedTagsResult)
    return __ret__.apply(lambda __response__: GetProjectProtectedTagsResult(
        id=pulumi.get(__response__, 'id'),
        project=pulumi.get(__response__, 'project'),
        protected_tags=pulumi.get(__response__, 'protected_tags')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs

__all__ = [
    'GetProjectIssueResult',
    'AwaitableGetProjectIssueResult',
    'get_project_issue',
    'get_project_issue_output',
]

@pulumi.output_type
class GetProjectIssueResult:
    """
    A collection of values returned by getProjectIssue.
    """
    def __init__(__self__, assignee_ids=None, author_id=None, closed_at=None, closed_by_user_id=None, confidential=None, created_at=None, description=None, discussion_locked=None, discussion_to_resolve=None, downvotes=None, due_date=None, epic_id=None, epic_issue_id=None, external_id=None, human_time_estimate=None, human_total_time_spent=None, id=None, iid=None, issue_id=None, issue_link_id=None, issue_type=None, labels=None, links=None, merge_request_to_resolve_discussions_of=None, merge_requests_count=None, milestone_id=None, moved_to_id=None, project=None, references=None, state=None, subscribed=None, task_completion_statuses=None, time_estimate=None, title=None, total_time_spent=None, updated_at=None, upvotes=None, user_notes_count=None, web_url=None, weight=None):
        if assignee_ids and not isinstance(assignee_ids, list):
            raise TypeError("Expected argument 'assignee_ids' to be a list")
        pulumi.set(__self__, "assignee_ids", assignee_ids)
        if author_id and not isinstance(author_id, int):
            raise TypeError("Expected argument 'author_id' to be a int")
        pulumi.set(__self__, "author_id", author_id)
        if closed_at and not isinstance(closed_at, str):
            raise TypeError("Expected argument 'closed_at' to be a str")
        pulumi.set(__self__, "closed_at", closed_at)
        if closed_by_user_id and not isinstance(closed_by_user_id, int):
            raise TypeError("Expected argument 'closed_by_user_id' to be a int")
        pulumi.set(__self__, "closed_by_user_id", closed_by_user_id)
        if confidential and not isinstance(confidential, bool):
            raise TypeError("Expected argument 'confidential' to be a bool")
        pulumi.set(__self__, "confidential", confidential)
        if created_at and not isinstance(created_at, str):
            raise TypeError("Expected argument 'created_at' to be a str")
        pulumi.set(__self__, "created_at", created_at)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if discussion_locked and not isinstance(discussion_locked, bool):
            raise TypeError("Expected argument 'discussion_locked' to be a bool")
        pulumi.set(__self__, "discussion_locked", discussion_locked)
        if discussion_to_resolve and not isinstance(discussion_to_resolve, str):
            raise TypeError("Expected argument 'discussion_to_resolve' to be a str")
        pulumi.set(__self__, "discussion_to_resolve", discussion_to_resolve)
        if downvotes and not isinstance(downvotes, int):
            raise TypeError("Expected argument 'downvotes' to be a int")
        pulumi.set(__self__, "downvotes", downvotes)
        if due_date and not isinstance(due_date, str):
            raise TypeError("Expected argument 'due_date' to be a str")
        pulumi.set(__self__, "due_date", due_date)
        if epic_id and not isinstance(epic_id, int):
            raise TypeError("Expected argument 'epic_id' to be a int")
        pulumi.set(__self__, "epic_id", epic_id)
        if epic_issue_id and not isinstance(epic_issue_id, int):
            raise TypeError("Expected argument 'epic_issue_id' to be a int")
        pulumi.set(__self__, "epic_issue_id", epic_issue_id)
        if external_id and not isinstance(external_id, str):
            raise TypeError("Expected argument 'external_id' to be a str")
        pulumi.set(__self__, "external_id", external_id)
        if human_time_estimate and not isinstance(human_time_estimate, str):
            raise TypeError("Expected argument 'human_time_estimate' to be a str")
        pulumi.set(__self__, "human_time_estimate", human_time_estimate)
        if human_total_time_spent and not isinstance(human_total_time_spent, str):
            raise TypeError("Expected argument 'human_total_time_spent' to be a str")
        pulumi.set(__self__, "human_total_time_spent", human_total_time_spent)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if iid and not isinstance(iid, int):
            raise TypeError("Expected argument 'iid' to be a int")
        pulumi.set(__self__, "iid", iid)
        if issue_id and not isinstance(issue_id, int):
            raise TypeError("Expected argument 'issue_id' to be a int")
        pulumi.set(__self__, "issue_id", issue_id)
        if issue_link_id and not isinstance(issue_link_id, int):
            raise TypeError("Expected argument 'issue_link_id' to be a int")
        pulumi.set(__self__, "issue_link_id", issue_link_id)
        if issue_type and not isinstance(issue_type, str):
            raise TypeError("Expected argument 'issue_type' to be a str")
        pulumi.set(__self__, "issue_type", issue_type)
        if labels and not isinstance(labels, list):
            raise TypeError("Expected argument 'labels' to be a list")
        pulumi.set(__self__, "labels", labels)
        if links and not isinstance(links, dict):
            raise TypeError("Expected argument 'links' to be a dict")
        pulumi.set(__self__, "links", links)
        if merge_request_to_resolve_discussions_of and not isinstance(merge_request_to_resolve_discussions_of, int):
            raise TypeError("Expected argument 'merge_request_to_resolve_discussions_of' to be a int")
        pulumi.set(__self__, "merge_request_to_resolve_discussions_of", merge_request_to_resolve_discussions_of)
        if merge_requests_count and not isinstance(merge_requests_count, int):
            raise TypeError("Expected argument 'merge_requests_count' to be a int")
        pulumi.set(__self__, "merge_requests_count", merge_requests_count)
        if milestone_id and not isinstance(milestone_id, int):
            raise TypeError("Expected argument 'milestone_id' to be a int")
        pulumi.set(__self__, "milestone_id", milestone_id)
        if moved_to_id and not isinstance(moved_to_id, int):
            raise TypeError("Expected argument 'moved_to_id' to be a int")
        pulumi.set(__self__, "moved_to_id", moved_to_id)
        if project and not isinstance(project, str):
            raise TypeError("Expected argument 'project' to be a str")
        pulumi.set(__self__, "project", project)
        if references and not isinstance(references, dict):
            raise TypeError("Expected argument 'references' to be a dict")
        pulumi.set(__self__, "references", references)
        if state and not isinstance(state, str):
            raise TypeError("Expected argument 'state' to be a str")
        pulumi.set(__self__, "state", state)
        if subscribed and not isinstance(subscribed, bool):
            raise TypeError("Expected argument 'subscribed' to be a bool")
        pulumi.set(__self__, "subscribed", subscribed)
        if task_completion_statuses and not isinstance(task_completion_statuses, list):
            raise TypeError("Expected argument 'task_completion_statuses' to be a list")
        pulumi.set(__self__, "task_completion_statuses", task_completion_statuses)
        if time_estimate and not isinstance(time_estimate, int):
            raise TypeError("Expected argument 'time_estimate' to be a int")
        pulumi.set(__self__, "time_estimate", time_estimate)
        if title and not isinstance(title, str):
            raise TypeError("Expected argument 'title' to be a str")
        pulumi.set(__self__, "title", title)
        if total_time_spent and not isinstance(total_time_spent, int):
            raise TypeError("Expected argument 'total_time_spent' to be a int")
        pulumi.set(__self__, "total_time_spent", total_time_spent)
        if updated_at and not isinstance(updated_at, str):
            raise TypeError("Expected argument 'updated_at' to be a str")
        pulumi.set(__self__, "updated_at", updated_at)
        if upvotes and not isinstance(upvotes, int):
            raise TypeError("Expected argument 'upvotes' to be a int")
        pulumi.set(__self__, "upvotes", upvotes)
        if user_notes_count and not isinstance(user_notes_count, int):
            raise TypeError("Expected argument 'user_notes_count' to be a int")
        pulumi.set(__self__, "user_notes_count", user_notes_count)
        if web_url and not isinstance(web_url, str):
            raise TypeError("Expected argument 'web_url' to be a str")
        pulumi.set(__self__, "web_url", web_url)
        if weight and not isinstance(weight, int):
            raise TypeError("Expected argument 'weight' to be a int")
        pulumi.set(__self__, "weight", weight)

    @property
    @pulumi.getter(name="assigneeIds")
    def assignee_ids(self) -> Sequence[int]:
        """
        The IDs of the users to assign the issue to.
        """
        return pulumi.get(self, "assignee_ids")

    @property
    @pulumi.getter(name="authorId")
    def author_id(self) -> int:
        """
        The ID of the author of the issue. Use `User` data source to get more information about the user.
        """
        return pulumi.get(self, "author_id")

    @property
    @pulumi.getter(name="closedAt")
    def closed_at(self) -> str:
        """
        When the issue was closed. Date time string, ISO 8601 formatted, for example 2016-03-11T03:45:40Z.
        """
        return pulumi.get(self, "closed_at")

    @property
    @pulumi.getter(name="closedByUserId")
    def closed_by_user_id(self) -> int:
        """
        The ID of the user that closed the issue. Use `User` data source to get more information about the user.
        """
        return pulumi.get(self, "closed_by_user_id")

    @property
    @pulumi.getter
    def confidential(self) -> bool:
        """
        Set an issue to be confidential.
        """
        return pulumi.get(self, "confidential")

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> str:
        """
        When the issue was created. Date time string, ISO 8601 formatted, for example 2016-03-11T03:45:40Z. Requires administrator or project/group owner rights.
        """
        return pulumi.get(self, "created_at")

    @property
    @pulumi.getter
    def description(self) -> str:
        """
        The description of an issue. Limited to 1,048,576 characters.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="discussionLocked")
    def discussion_locked(self) -> bool:
        """
        Whether the issue is locked for discussions or not.
        """
        return pulumi.get(self, "discussion_locked")

    @property
    @pulumi.getter(name="discussionToResolve")
    def discussion_to_resolve(self) -> str:
        """
        The ID of a discussion to resolve. This fills out the issue with a default description and mark the discussion as resolved. Use in combination with merge*request*to*resolve*discussions_of.
        """
        return pulumi.get(self, "discussion_to_resolve")

    @property
    @pulumi.getter
    def downvotes(self) -> int:
        """
        The number of downvotes the issue has received.
        """
        return pulumi.get(self, "downvotes")

    @property
    @pulumi.getter(name="dueDate")
    def due_date(self) -> str:
        """
        The due date. Date time string in the format YYYY-MM-DD, for example 2016-03-11.
        """
        return pulumi.get(self, "due_date")

    @property
    @pulumi.getter(name="epicId")
    def epic_id(self) -> int:
        """
        ID of the epic to add the issue to. Valid values are greater than or equal to 0.
        """
        return pulumi.get(self, "epic_id")

    @property
    @pulumi.getter(name="epicIssueId")
    def epic_issue_id(self) -> int:
        """
        The ID of the epic issue.
        """
        return pulumi.get(self, "epic_issue_id")

    @property
    @pulumi.getter(name="externalId")
    def external_id(self) -> str:
        """
        The external ID of the issue.
        """
        return pulumi.get(self, "external_id")

    @property
    @pulumi.getter(name="humanTimeEstimate")
    def human_time_estimate(self) -> str:
        """
        The human-readable time estimate of the issue.
        """
        return pulumi.get(self, "human_time_estimate")

    @property
    @pulumi.getter(name="humanTotalTimeSpent")
    def human_total_time_spent(self) -> str:
        """
        The human-readable total time spent of the issue.
        """
        return pulumi.get(self, "human_total_time_spent")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def iid(self) -> int:
        """
        The internal ID of the project's issue.
        """
        return pulumi.get(self, "iid")

    @property
    @pulumi.getter(name="issueId")
    def issue_id(self) -> int:
        """
        The instance-wide ID of the issue.
        """
        return pulumi.get(self, "issue_id")

    @property
    @pulumi.getter(name="issueLinkId")
    def issue_link_id(self) -> int:
        """
        The ID of the issue link.
        """
        return pulumi.get(self, "issue_link_id")

    @property
    @pulumi.getter(name="issueType")
    def issue_type(self) -> str:
        """
        The type of issue. Valid values are: `issue`, `incident`, `test_case`.
        """
        return pulumi.get(self, "issue_type")

    @property
    @pulumi.getter
    def labels(self) -> Sequence[str]:
        """
        The labels of an issue.
        """
        return pulumi.get(self, "labels")

    @property
    @pulumi.getter
    def links(self) -> Mapping[str, str]:
        """
        The links of the issue.
        """
        return pulumi.get(self, "links")

    @property
    @pulumi.getter(name="mergeRequestToResolveDiscussionsOf")
    def merge_request_to_resolve_discussions_of(self) -> int:
        """
        The IID of a merge request in which to resolve all issues. This fills out the issue with a default description and mark all discussions as resolved. When passing a description or title, these values take precedence over the default values.
        """
        return pulumi.get(self, "merge_request_to_resolve_discussions_of")

    @property
    @pulumi.getter(name="mergeRequestsCount")
    def merge_requests_count(self) -> int:
        """
        The number of merge requests associated with the issue.
        """
        return pulumi.get(self, "merge_requests_count")

    @property
    @pulumi.getter(name="milestoneId")
    def milestone_id(self) -> int:
        """
        The global ID of a milestone to assign issue. To find the milestone_id associated with a milestone, view an issue with the milestone assigned and use the API to retrieve the issue's details.
        """
        return pulumi.get(self, "milestone_id")

    @property
    @pulumi.getter(name="movedToId")
    def moved_to_id(self) -> int:
        """
        The ID of the issue that was moved to.
        """
        return pulumi.get(self, "moved_to_id")

    @property
    @pulumi.getter
    def project(self) -> str:
        """
        The name or ID of the project.
        """
        return pulumi.get(self, "project")

    @property
    @pulumi.getter
    def references(self) -> Mapping[str, str]:
        """
        The references of the issue.
        """
        return pulumi.get(self, "references")

    @property
    @pulumi.getter
    def state(self) -> str:
        """
        The state of the issue. Valid values are: `opened`, `closed`.
        """
        return pulumi.get(self, "state")

    @property
    @pulumi.getter
    def subscribed(self) -> bool:
        """
        Whether the authenticated user is subscribed to the issue or not.
        """
        return pulumi.get(self, "subscribed")

    @property
    @pulumi.getter(name="taskCompletionStatuses")
    def task_completion_statuses(self) -> Sequence['outputs.GetProjectIssueTaskCompletionStatusResult']:
        """
        The task completion status. It's always a one element list.
        """
        return pulumi.get(self, "task_completion_statuses")

    @property
    @pulumi.getter(name="timeEstimate")
    def time_estimate(self) -> int:
        """
        The time estimate of the issue.
        """
        return pulumi.get(self, "time_estimate")

    @property
    @pulumi.getter
    def title(self) -> str:
        """
        The title of the issue.
        """
        return pulumi.get(self, "title")

    @property
    @pulumi.getter(name="totalTimeSpent")
    def total_time_spent(self) -> int:
        """
        The total time spent of the issue.
        """
        return pulumi.get(self, "total_time_spent")

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> str:
        """
        When the issue was updated. Date time string, ISO 8601 formatted, for example 2016-03-11T03:45:40Z.
        """
        return pulumi.get(self, "updated_at")

    @property
    @pulumi.getter
    def upvotes(self) -> int:
        """
        The number of upvotes the issue has received.
        """
        return pulumi.get(self, "upvotes")

    @property
    @pulumi.getter(name="userNotesCount")
    def user_notes_count(self) -> int:
        """
        The number of user notes on the issue.
        """
        return pulumi.get(self, "user_notes_count")

    @property
    @pulumi.getter(name="webUrl")
    def web_url(self) -> str:
        """
        The web URL of the issue.
        """
        return pulumi.get(self, "web_url")

    @property
    @pulumi.getter
    def weight(self) -> int:
        """
        The weight of the issue. Valid values are greater than or equal to 0.
        """
        return pulumi.get(self, "weight")


class AwaitableGetProjectIssueResult(GetProjectIssueResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetProjectIssueResult(
            assignee_ids=self.assignee_ids,
            author_id=self.author_id,
            closed_at=self.closed_at,
            closed_by_user_id=self.closed_by_user_id,
            confidential=self.confidential,
            created_at=self.created_at,
            description=self.description,
            discussion_locked=self.discussion_locked,
            discussion_to_resolve=self.discussion_to_resolve,
            downvotes=self.downvotes,
            due_date=self.due_date,
            epic_id=self.epic_id,
            epic_issue_id=self.epic_issue_id,
            external_id=self.external_id,
            human_time_estimate=self.human_time_estimate,
            human_total_time_spent=self.human_total_time_spent,
            id=self.id,
            iid=self.iid,
            issue_id=self.issue_id,
            issue_link_id=self.issue_link_id,
            issue_type=self.issue_type,
            labels=self.labels,
            links=self.links,
            merge_request_to_resolve_discussions_of=self.merge_request_to_resolve_discussions_of,
            merge_requests_count=self.merge_requests_count,
            milestone_id=self.milestone_id,
            moved_to_id=self.moved_to_id,
            project=self.project,
            references=self.references,
            state=self.state,
            subscribed=self.subscribed,
            task_completion_statuses=self.task_completion_statuses,
            time_estimate=self.time_estimate,
            title=self.title,
            total_time_spent=self.total_time_spent,
            updated_at=self.updated_at,
            upvotes=self.upvotes,
            user_notes_count=self.user_notes_count,
            web_url=self.web_url,
            weight=self.weight)


def get_project_issue(iid: Optional[int] = None,
                      project: Optional[str] = None,
                      opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetProjectIssueResult:
    """
    The `ProjectIssue` data source allows to retrieve details about an issue in a project.

    **Upstream API**: [GitLab API docs](https://docs.gitlab.com/ee/api/issues.html)

    ## Example Usage

    ```python
    import pulumi
    import pulumi_gitlab as gitlab

    foo = gitlab.get_project(path_with_namespace="foo/bar/baz")
    welcome_issue = gitlab.get_project_issue(project=foo.id,
        iid=1)
    pulumi.export("welcomeIssueWebUrl", web_url)
    ```


    :param int iid: The internal ID of the project's issue.
    :param str project: The name or ID of the project.
    """
    __args__ = dict()
    __args__['iid'] = iid
    __args__['project'] = project
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('gitlab:index/getProjectIssue:getProjectIssue', __args__, opts=opts, typ=GetProjectIssueResult).value

    return AwaitableGetProjectIssueResult(
        assignee_ids=pulumi.get(__ret__, 'assignee_ids'),
        author_id=pulumi.get(__ret__, 'author_id'),
        closed_at=pulumi.get(__ret__, 'closed_at'),
        closed_by_user_id=pulumi.get(__ret__, 'closed_by_user_id'),
        confidential=pulumi.get(__ret__, 'confidential'),
        created_at=pulumi.get(__ret__, 'created_at'),
        description=pulumi.get(__ret__, 'description'),
        discussion_locked=pulumi.get(__ret__, 'discussion_locked'),
        discussion_to_resolve=pulumi.get(__ret__, 'discussion_to_resolve'),
        downvotes=pulumi.get(__ret__, 'downvotes'),
        due_date=pulumi.get(__ret__, 'due_date'),
        epic_id=pulumi.get(__ret__, 'epic_id'),
        epic_issue_id=pulumi.get(__ret__, 'epic_issue_id'),
        external_id=pulumi.get(__ret__, 'external_id'),
        human_time_estimate=pulumi.get(__ret__, 'human_time_estimate'),
        human_total_time_spent=pulumi.get(__ret__, 'human_total_time_spent'),
        id=pulumi.get(__ret__, 'id'),
        iid=pulumi.get(__ret__, 'iid'),
        issue_id=pulumi.get(__ret__, 'issue_id'),
        issue_link_id=pulumi.get(__ret__, 'issue_link_id'),
        issue_type=pulumi.get(__ret__, 'issue_type'),
        labels=pulumi.get(__ret__, 'labels'),
        links=pulumi.get(__ret__, 'links'),
        merge_request_to_resolve_discussions_of=pulumi.get(__ret__, 'merge_request_to_resolve_discussions_of'),
        merge_requests_count=pulumi.get(__ret__, 'merge_requests_count'),
        milestone_id=pulumi.get(__ret__, 'milestone_id'),
        moved_to_id=pulumi.get(__ret__, 'moved_to_id'),
        project=pulumi.get(__ret__, 'project'),
        references=pulumi.get(__ret__, 'references'),
        state=pulumi.get(__ret__, 'state'),
        subscribed=pulumi.get(__ret__, 'subscribed'),
        task_completion_statuses=pulumi.get(__ret__, 'task_completion_statuses'),
        time_estimate=pulumi.get(__ret__, 'time_estimate'),
        title=pulumi.get(__ret__, 'title'),
        total_time_spent=pulumi.get(__ret__, 'total_time_spent'),
        updated_at=pulumi.get(__ret__, 'updated_at'),
        upvotes=pulumi.get(__ret__, 'upvotes'),
        user_notes_count=pulumi.get(__ret__, 'user_notes_count'),
        web_url=pulumi.get(__ret__, 'web_url'),
        weight=pulumi.get(__ret__, 'weight'))
def get_project_issue_output(iid: Optional[pulumi.Input[int]] = None,
                             project: Optional[pulumi.Input[str]] = None,
                             opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetProjectIssueResult]:
    """
    The `ProjectIssue` data source allows to retrieve details about an issue in a project.

    **Upstream API**: [GitLab API docs](https://docs.gitlab.com/ee/api/issues.html)

    ## Example Usage

    ```python
    import pulumi
    import pulumi_gitlab as gitlab

    foo = gitlab.get_project(path_with_namespace="foo/bar/baz")
    welcome_issue = gitlab.get_project_issue(project=foo.id,
        iid=1)
    pulumi.export("welcomeIssueWebUrl", web_url)
    ```


    :param int iid: The internal ID of the project's issue.
    :param str project: The name or ID of the project.
    """
    __args__ = dict()
    __args__['iid'] = iid
    __args__['project'] = project
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('gitlab:index/getProjectIssue:getProjectIssue', __args__, opts=opts, typ=GetProjectIssueResult)
    return __ret__.apply(lambda __response__: GetProjectIssueResult(
        assignee_ids=pulumi.get(__response__, 'assignee_ids'),
        author_id=pulumi.get(__response__, 'author_id'),
        closed_at=pulumi.get(__response__, 'closed_at'),
        closed_by_user_id=pulumi.get(__response__, 'closed_by_user_id'),
        confidential=pulumi.get(__response__, 'confidential'),
        created_at=pulumi.get(__response__, 'created_at'),
        description=pulumi.get(__response__, 'description'),
        discussion_locked=pulumi.get(__response__, 'discussion_locked'),
        discussion_to_resolve=pulumi.get(__response__, 'discussion_to_resolve'),
        downvotes=pulumi.get(__response__, 'downvotes'),
        due_date=pulumi.get(__response__, 'due_date'),
        epic_id=pulumi.get(__response__, 'epic_id'),
        epic_issue_id=pulumi.get(__response__, 'epic_issue_id'),
        external_id=pulumi.get(__response__, 'external_id'),
        human_time_estimate=pulumi.get(__response__, 'human_time_estimate'),
        human_total_time_spent=pulumi.get(__response__, 'human_total_time_spent'),
        id=pulumi.get(__response__, 'id'),
        iid=pulumi.get(__response__, 'iid'),
        issue_id=pulumi.get(__response__, 'issue_id'),
        issue_link_id=pulumi.get(__response__, 'issue_link_id'),
        issue_type=pulumi.get(__response__, 'issue_type'),
        labels=pulumi.get(__response__, 'labels'),
        links=pulumi.get(__response__, 'links'),
        merge_request_to_resolve_discussions_of=pulumi.get(__response__, 'merge_request_to_resolve_discussions_of'),
        merge_requests_count=pulumi.get(__response__, 'merge_requests_count'),
        milestone_id=pulumi.get(__response__, 'milestone_id'),
        moved_to_id=pulumi.get(__response__, 'moved_to_id'),
        project=pulumi.get(__response__, 'project'),
        references=pulumi.get(__response__, 'references'),
        state=pulumi.get(__response__, 'state'),
        subscribed=pulumi.get(__response__, 'subscribed'),
        task_completion_statuses=pulumi.get(__response__, 'task_completion_statuses'),
        time_estimate=pulumi.get(__response__, 'time_estimate'),
        title=pulumi.get(__response__, 'title'),
        total_time_spent=pulumi.get(__response__, 'total_time_spent'),
        updated_at=pulumi.get(__response__, 'updated_at'),
        upvotes=pulumi.get(__response__, 'upvotes'),
        user_notes_count=pulumi.get(__response__, 'user_notes_count'),
        web_url=pulumi.get(__response__, 'web_url'),
        weight=pulumi.get(__response__, 'weight')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['UserArgs', 'User']

@pulumi.input_type
class UserArgs:
    def __init__(__self__, *,
                 email: pulumi.Input[str],
                 username: pulumi.Input[str],
                 can_create_group: Optional[pulumi.Input[bool]] = None,
                 extern_uid: Optional[pulumi.Input[str]] = None,
                 external_provider: Optional[pulumi.Input[str]] = None,
                 is_admin: Optional[pulumi.Input[bool]] = None,
                 is_external: Optional[pulumi.Input[bool]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 namespace_id: Optional[pulumi.Input[int]] = None,
                 note: Optional[pulumi.Input[str]] = None,
                 password: Optional[pulumi.Input[str]] = None,
                 projects_limit: Optional[pulumi.Input[int]] = None,
                 reset_password: Optional[pulumi.Input[bool]] = None,
                 skip_confirmation: Optional[pulumi.Input[bool]] = None,
                 state: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a User resource.
        :param pulumi.Input[str] email: The e-mail address of the user.
        :param pulumi.Input[str] username: The username of the user.
        :param pulumi.Input[bool] can_create_group: Boolean, defaults to false. Whether to allow the user to create groups.
        :param pulumi.Input[str] extern_uid: String, a specific external authentication provider UID.
        :param pulumi.Input[str] external_provider: String, the external provider.
        :param pulumi.Input[bool] is_admin: Boolean, defaults to false.  Whether to enable administrative privileges
        :param pulumi.Input[bool] is_external: Boolean, defaults to false. Whether a user has access only to some internal or private projects. External users can only access projects to which they are explicitly granted access.
        :param pulumi.Input[str] name: The name of the user.
        :param pulumi.Input[int] namespace_id: The ID of the user's namespace. Available since GitLab 14.10.
        :param pulumi.Input[str] note: The note associated to the user.
        :param pulumi.Input[str] password: The password of the user.
        :param pulumi.Input[int] projects_limit: Integer, defaults to 0.  Number of projects user can create.
        :param pulumi.Input[bool] reset_password: Boolean, defaults to false. Send user password reset link.
        :param pulumi.Input[bool] skip_confirmation: Boolean, defaults to true. Whether to skip confirmation.
        :param pulumi.Input[str] state: String, defaults to 'active'. The state of the user account. Valid values are `active`, `deactivated`, `blocked`.
        """
        pulumi.set(__self__, "email", email)
        pulumi.set(__self__, "username", username)
        if can_create_group is not None:
            pulumi.set(__self__, "can_create_group", can_create_group)
        if extern_uid is not None:
            pulumi.set(__self__, "extern_uid", extern_uid)
        if external_provider is not None:
            pulumi.set(__self__, "external_provider", external_provider)
        if is_admin is not None:
            pulumi.set(__self__, "is_admin", is_admin)
        if is_external is not None:
            pulumi.set(__self__, "is_external", is_external)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if namespace_id is not None:
            pulumi.set(__self__, "namespace_id", namespace_id)
        if note is not None:
            pulumi.set(__self__, "note", note)
        if password is not None:
            pulumi.set(__self__, "password", password)
        if projects_limit is not None:
            pulumi.set(__self__, "projects_limit", projects_limit)
        if reset_password is not None:
            pulumi.set(__self__, "reset_password", reset_password)
        if skip_confirmation is not None:
            pulumi.set(__self__, "skip_confirmation", skip_confirmation)
        if state is not None:
            pulumi.set(__self__, "state", state)

    @property
    @pulumi.getter
    def email(self) -> pulumi.Input[str]:
        """
        The e-mail address of the user.
        """
        return pulumi.get(self, "email")

    @email.setter
    def email(self, value: pulumi.Input[str]):
        pulumi.set(self, "email", value)

    @property
    @pulumi.getter
    def username(self) -> pulumi.Input[str]:
        """
        The username of the user.
        """
        return pulumi.get(self, "username")

    @username.setter
    def username(self, value: pulumi.Input[str]):
        pulumi.set(self, "username", value)

    @property
    @pulumi.getter(name="canCreateGroup")
    def can_create_group(self) -> Optional[pulumi.Input[bool]]:
        """
        Boolean, defaults to false. Whether to allow the user to create groups.
        """
        return pulumi.get(self, "can_create_group")

    @can_create_group.setter
    def can_create_group(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "can_create_group", value)

    @property
    @pulumi.getter(name="externUid")
    def extern_uid(self) -> Optional[pulumi.Input[str]]:
        """
        String, a specific external authentication provider UID.
        """
        return pulumi.get(self, "extern_uid")

    @extern_uid.setter
    def extern_uid(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "extern_uid", value)

    @property
    @pulumi.getter(name="externalProvider")
    def external_provider(self) -> Optional[pulumi.Input[str]]:
        """
        String, the external provider.
        """
        return pulumi.get(self, "external_provider")

    @external_provider.setter
    def external_provider(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "external_provider", value)

    @property
    @pulumi.getter(name="isAdmin")
    def is_admin(self) -> Optional[pulumi.Input[bool]]:
        """
        Boolean, defaults to false.  Whether to enable administrative privileges
        """
        return pulumi.get(self, "is_admin")

    @is_admin.setter
    def is_admin(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "is_admin", value)

    @property
    @pulumi.getter(name="isExternal")
    def is_external(self) -> Optional[pulumi.Input[bool]]:
        """
        Boolean, defaults to false. Whether a user has access only to some internal or private projects. External users can only access projects to which they are explicitly granted access.
        """
        return pulumi.get(self, "is_external")

    @is_external.setter
    def is_external(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "is_external", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the user.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="namespaceId")
    def namespace_id(self) -> Optional[pulumi.Input[int]]:
        """
        The ID of the user's namespace. Available since GitLab 14.10.
        """
        return pulumi.get(self, "namespace_id")

    @namespace_id.setter
    def namespace_id(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "namespace_id", value)

    @property
    @pulumi.getter
    def note(self) -> Optional[pulumi.Input[str]]:
        """
        The note associated to the user.
        """
        return pulumi.get(self, "note")

    @note.setter
    def note(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "note", value)

    @property
    @pulumi.getter
    def password(self) -> Optional[pulumi.Input[str]]:
        """
        The password of the user.
        """
        return pulumi.get(self, "password")

    @password.setter
    def password(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "password", value)

    @property
    @pulumi.getter(name="projectsLimit")
    def projects_limit(self) -> Optional[pulumi.Input[int]]:
        """
        Integer, defaults to 0.  Number of projects user can create.
        """
        return pulumi.get(self, "projects_limit")

    @projects_limit.setter
    def projects_limit(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "projects_limit", value)

    @property
    @pulumi.getter(name="resetPassword")
    def reset_password(self) -> Optional[pulumi.Input[bool]]:
        """
        Boolean, defaults to false. Send user password reset link.
        """
        return pulumi.get(self, "reset_password")

    @reset_password.setter
    def reset_password(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "reset_password", value)

    @property
    @pulumi.getter(name="skipConfirmation")
    def skip_confirmation(self) -> Optional[pulumi.Input[bool]]:
        """
        Boolean, defaults to true. Whether to skip confirmation.
        """
        return pulumi.get(self, "skip_confirmation")

    @skip_confirmation.setter
    def skip_confirmation(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "skip_confirmation", value)

    @property
    @pulumi.getter
    def state(self) -> Optional[pulumi.Input[str]]:
        """
        String, defaults to 'active'. The state of the user account. Valid values are `active`, `deactivated`, `blocked`.
        """
        return pulumi.get(self, "state")

    @state.setter
    def state(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "state", value)


@pulumi.input_type
class _UserState:
    def __init__(__self__, *,
                 can_create_group: Optional[pulumi.Input[bool]] = None,
                 email: Optional[pulumi.Input[str]] = None,
                 extern_uid: Optional[pulumi.Input[str]] = None,
                 external_provider: Optional[pulumi.Input[str]] = None,
                 is_admin: Optional[pulumi.Input[bool]] = None,
                 is_external: Optional[pulumi.Input[bool]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 namespace_id: Optional[pulumi.Input[int]] = None,
                 note: Optional[pulumi.Input[str]] = None,
                 password: Optional[pulumi.Input[str]] = None,
                 projects_limit: Optional[pulumi.Input[int]] = None,
                 reset_password: Optional[pulumi.Input[bool]] = None,
                 skip_confirmation: Optional[pulumi.Input[bool]] = None,
                 state: Optional[pulumi.Input[str]] = None,
                 username: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering User resources.
        :param pulumi.Input[bool] can_create_group: Boolean, defaults to false. Whether to allow the user to create groups.
        :param pulumi.Input[str] email: The e-mail address of the user.
        :param pulumi.Input[str] extern_uid: String, a specific external authentication provider UID.
        :param pulumi.Input[str] external_provider: String, the external provider.
        :param pulumi.Input[bool] is_admin: Boolean, defaults to false.  Whether to enable administrative privileges
        :param pulumi.Input[bool] is_external: Boolean, defaults to false. Whether a user has access only to some internal or private projects. External users can only access projects to which they are explicitly granted access.
        :param pulumi.Input[str] name: The name of the user.
        :param pulumi.Input[int] namespace_id: The ID of the user's namespace. Available since GitLab 14.10.
        :param pulumi.Input[str] note: The note associated to the user.
        :param pulumi.Input[str] password: The password of the user.
        :param pulumi.Input[int] projects_limit: Integer, defaults to 0.  Number of projects user can create.
        :param pulumi.Input[bool] reset_password: Boolean, defaults to false. Send user password reset link.
        :param pulumi.Input[bool] skip_confirmation: Boolean, defaults to true. Whether to skip confirmation.
        :param pulumi.Input[str] state: String, defaults to 'active'. The state of the user account. Valid values are `active`, `deactivated`, `blocked`.
        :param pulumi.Input[str] username: The username of the user.
        """
        if can_create_group is not None:
            pulumi.set(__self__, "can_create_group", can_create_group)
        if email is not None:
            pulumi.set(__self__, "email", email)
        if extern_uid is not None:
            pulumi.set(__self__, "extern_uid", extern_uid)
        if external_provider is not None:
            pulumi.set(__self__, "external_provider", external_provider)
        if is_admin is not None:
            pulumi.set(__self__, "is_admin", is_admin)
        if is_external is not None:
            pulumi.set(__self__, "is_external", is_external)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if namespace_id is not None:
            pulumi.set(__self__, "namespace_id", namespace_id)
        if note is not None:
            pulumi.set(__self__, "note", note)
        if password is not None:
            pulumi.set(__self__, "password", password)
        if projects_limit is not None:
            pulumi.set(__self__, "projects_limit", projects_limit)
        if reset_password is not None:
            pulumi.set(__self__, "reset_password", reset_password)
        if skip_confirmation is not None:
            pulumi.set(__self__, "skip_confirmation", skip_confirmation)
        if state is not None:
            pulumi.set(__self__, "state", state)
        if username is not None:
            pulumi.set(__self__, "username", username)

    @property
    @pulumi.getter(name="canCreateGroup")
    def can_create_group(self) -> Optional[pulumi.Input[bool]]:
        """
        Boolean, defaults to false. Whether to allow the user to create groups.
        """
        return pulumi.get(self, "can_create_group")

    @can_create_group.setter
    def can_create_group(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "can_create_group", value)

    @property
    @pulumi.getter
    def email(self) -> Optional[pulumi.Input[str]]:
        """
        The e-mail address of the user.
        """
        return pulumi.get(self, "email")

    @email.setter
    def email(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "email", value)

    @property
    @pulumi.getter(name="externUid")
    def extern_uid(self) -> Optional[pulumi.Input[str]]:
        """
        String, a specific external authentication provider UID.
        """
        return pulumi.get(self, "extern_uid")

    @extern_uid.setter
    def extern_uid(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "extern_uid", value)

    @property
    @pulumi.getter(name="externalProvider")
    def external_provider(self) -> Optional[pulumi.Input[str]]:
        """
        String, the external provider.
        """
        return pulumi.get(self, "external_provider")

    @external_provider.setter
    def external_provider(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "external_provider", value)

    @property
    @pulumi.getter(name="isAdmin")
    def is_admin(self) -> Optional[pulumi.Input[bool]]:
        """
        Boolean, defaults to false.  Whether to enable administrative privileges
        """
        return pulumi.get(self, "is_admin")

    @is_admin.setter
    def is_admin(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "is_admin", value)

    @property
    @pulumi.getter(name="isExternal")
    def is_external(self) -> Optional[pulumi.Input[bool]]:
        """
        Boolean, defaults to false. Whether a user has access only to some internal or private projects. External users can only access projects to which they are explicitly granted access.
        """
        return pulumi.get(self, "is_external")

    @is_external.setter
    def is_external(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "is_external", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the user.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="namespaceId")
    def namespace_id(self) -> Optional[pulumi.Input[int]]:
        """
        The ID of the user's namespace. Available since GitLab 14.10.
        """
        return pulumi.get(self, "namespace_id")

    @namespace_id.setter
    def namespace_id(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "namespace_id", value)

    @property
    @pulumi.getter
    def note(self) -> Optional[pulumi.Input[str]]:
        """
        The note associated to the user.
        """
        return pulumi.get(self, "note")

    @note.setter
    def note(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "note", value)

    @property
    @pulumi.getter
    def password(self) -> Optional[pulumi.Input[str]]:
        """
        The password of the user.
        """
        return pulumi.get(self, "password")

    @password.setter
    def password(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "password", value)

    @property
    @pulumi.getter(name="projectsLimit")
    def projects_limit(self) -> Optional[pulumi.Input[int]]:
        """
        Integer, defaults to 0.  Number of projects user can create.
        """
        return pulumi.get(self, "projects_limit")

    @projects_limit.setter
    def projects_limit(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "projects_limit", value)

    @property
    @pulumi.getter(name="resetPassword")
    def reset_password(self) -> Optional[pulumi.Input[bool]]:
        """
        Boolean, defaults to false. Send user password reset link.
        """
        return pulumi.get(self, "reset_password")

    @reset_password.setter
    def reset_password(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "reset_password", value)

    @property
    @pulumi.getter(name="skipConfirmation")
    def skip_confirmation(self) -> Optional[pulumi.Input[bool]]:
        """
        Boolean, defaults to true. Whether to skip confirmation.
        """
        return pulumi.get(self, "skip_confirmation")

    @skip_confirmation.setter
    def skip_confirmation(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "skip_confirmation", value)

    @property
    @pulumi.getter
    def state(self) -> Optional[pulumi.Input[str]]:
        """
        String, defaults to 'active'. The state of the user account. Valid values are `active`, `deactivated`, `blocked`.
        """
        return pulumi.get(self, "state")

    @state.setter
    def state(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "state", value)

    @property
    @pulumi.getter
    def username(self) -> Optional[pulumi.Input[str]]:
        """
        The username of the user.
        """
        return pulumi.get(self, "username")

    @username.setter
    def username(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "username", value)


class User(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 can_create_group: Optional[pulumi.Input[bool]] = None,
                 email: Optional[pulumi.Input[str]] = None,
                 extern_uid: Optional[pulumi.Input[str]] = None,
                 external_provider: Optional[pulumi.Input[str]] = None,
                 is_admin: Optional[pulumi.Input[bool]] = None,
                 is_external: Optional[pulumi.Input[bool]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 namespace_id: Optional[pulumi.Input[int]] = None,
                 note: Optional[pulumi.Input[str]] = None,
                 password: Optional[pulumi.Input[str]] = None,
                 projects_limit: Optional[pulumi.Input[int]] = None,
                 reset_password: Optional[pulumi.Input[bool]] = None,
                 skip_confirmation: Optional[pulumi.Input[bool]] = None,
                 state: Optional[pulumi.Input[str]] = None,
                 username: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        The `User` resource allows to manage the lifecycle of a user.

        > the provider needs to be configured with admin-level access for this resource to work.

        > You must specify either password or reset_password.

        **Upstream API**: [GitLab REST API docs](https://docs.gitlab.com/ee/api/users.html)

        ## Example Usage

        ```python
        import pulumi
        import pulumi_gitlab as gitlab

        example = gitlab.User("example",
            name="Example Foo",
            username="example",
            password="superPassword",
            email="gitlab@user.create",
            is_admin=True,
            projects_limit=4,
            can_create_group=False,
            is_external=True,
            reset_password=False)
        ```

        ## Import

        Starting in Terraform v1.5.0 you can use an import block to import `gitlab_user`. For example:

        terraform

        import {

          to = gitlab_user.example

          id = "see CLI command below for ID"

        }

        Import using the CLI is supported using the following syntax:

        ```sh
        $ pulumi import gitlab:index/user:User You can import a user to terraform state using `<resource> <id>`.
        ```

        The `id` must be an integer for the id of the user you want to import,

        for example:

        ```sh
        $ pulumi import gitlab:index/user:User example 42
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[bool] can_create_group: Boolean, defaults to false. Whether to allow the user to create groups.
        :param pulumi.Input[str] email: The e-mail address of the user.
        :param pulumi.Input[str] extern_uid: String, a specific external authentication provider UID.
        :param pulumi.Input[str] external_provider: String, the external provider.
        :param pulumi.Input[bool] is_admin: Boolean, defaults to false.  Whether to enable administrative privileges
        :param pulumi.Input[bool] is_external: Boolean, defaults to false. Whether a user has access only to some internal or private projects. External users can only access projects to which they are explicitly granted access.
        :param pulumi.Input[str] name: The name of the user.
        :param pulumi.Input[int] namespace_id: The ID of the user's namespace. Available since GitLab 14.10.
        :param pulumi.Input[str] note: The note associated to the user.
        :param pulumi.Input[str] password: The password of the user.
        :param pulumi.Input[int] projects_limit: Integer, defaults to 0.  Number of projects user can create.
        :param pulumi.Input[bool] reset_password: Boolean, defaults to false. Send user password reset link.
        :param pulumi.Input[bool] skip_confirmation: Boolean, defaults to true. Whether to skip confirmation.
        :param pulumi.Input[str] state: String, defaults to 'active'. The state of the user account. Valid values are `active`, `deactivated`, `blocked`.
        :param pulumi.Input[str] username: The username of the user.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: UserArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        The `User` resource allows to manage the lifecycle of a user.

        > the provider needs to be configured with admin-level access for this resource to work.

        > You must specify either password or reset_password.

        **Upstream API**: [GitLab REST API docs](https://docs.gitlab.com/ee/api/users.html)

        ## Example Usage

        ```python
        import pulumi
        import pulumi_gitlab as gitlab

        example = gitlab.User("example",
            name="Example Foo",
            username="example",
            password="superPassword",
            email="gitlab@user.create",
            is_admin=True,
            projects_limit=4,
            can_create_group=False,
            is_external=True,
            reset_password=False)
        ```

        ## Import

        Starting in Terraform v1.5.0 you can use an import block to import `gitlab_user`. For example:

        terraform

        import {

          to = gitlab_user.example

          id = "see CLI command below for ID"

        }

        Import using the CLI is supported using the following syntax:

        ```sh
        $ pulumi import gitlab:index/user:User You can import a user to terraform state using `<resource> <id>`.
        ```

        The `id` must be an integer for the id of the user you want to import,

        for example:

        ```sh
        $ pulumi import gitlab:index/user:User example 42
        ```

        :param str resource_name: The name of the resource.
        :param UserArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(UserArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 can_create_group: Optional[pulumi.Input[bool]] = None,
                 email: Optional[pulumi.Input[str]] = None,
                 extern_uid: Optional[pulumi.Input[str]] = None,
                 external_provider: Optional[pulumi.Input[str]] = None,
                 is_admin: Optional[pulumi.Input[bool]] = None,
                 is_external: Optional[pulumi.Input[bool]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 namespace_id: Optional[pulumi.Input[int]] = None,
                 note: Optional[pulumi.Input[str]] = None,
                 password: Optional[pulumi.Input[str]] = None,
                 projects_limit: Optional[pulumi.Input[int]] = None,
                 reset_password: Optional[pulumi.Input[bool]] = None,
                 skip_confirmation: Optional[pulumi.Input[bool]] = None,
                 state: Optional[pulumi.Input[str]] = None,
                 username: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = UserArgs.__new__(UserArgs)

            __props__.__dict__["can_create_group"] = can_create_group
            if email is None and not opts.urn:
                raise TypeError("Missing required property 'email'")
            __props__.__dict__["email"] = email
            __props__.__dict__["extern_uid"] = extern_uid
            __props__.__dict__["external_provider"] = external_provider
            __props__.__dict__["is_admin"] = is_admin
            __props__.__dict__["is_external"] = is_external
            __props__.__dict__["name"] = name
            __props__.__dict__["namespace_id"] = namespace_id
            __props__.__dict__["note"] = note
            __props__.__dict__["password"] = None if password is None else pulumi.Output.secret(password)
            __props__.__dict__["projects_limit"] = projects_limit
            __props__.__dict__["reset_password"] = reset_password
            __props__.__dict__["skip_confirmation"] = skip_confirmation
            __props__.__dict__["state"] = state
            if username is None and not opts.urn:
                raise TypeError("Missing required property 'username'")
            __props__.__dict__["username"] = username
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["password"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(User, __self__).__init__(
            'gitlab:index/user:User',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            can_create_group: Optional[pulumi.Input[bool]] = None,
            email: Optional[pulumi.Input[str]] = None,
            extern_uid: Optional[pulumi.Input[str]] = None,
            external_provider: Optional[pulumi.Input[str]] = None,
            is_admin: Optional[pulumi.Input[bool]] = None,
            is_external: Optional[pulumi.Input[bool]] = None,
            name: Optional[pulumi.Input[str]] = None,
            namespace_id: Optional[pulumi.Input[int]] = None,
            note: Optional[pulumi.Input[str]] = None,
            password: Optional[pulumi.Input[str]] = None,
            projects_limit: Optional[pulumi.Input[int]] = None,
            reset_password: Optional[pulumi.Input[bool]] = None,
            skip_confirmation: Optional[pulumi.Input[bool]] = None,
            state: Optional[pulumi.Input[str]] = None,
            username: Optional[pulumi.Input[str]] = None) -> 'User':
        """
        Get an existing User resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[bool] can_create_group: Boolean, defaults to false. Whether to allow the user to create groups.
        :param pulumi.Input[str] email: The e-mail address of the user.
        :param pulumi.Input[str] extern_uid: String, a specific external authentication provider UID.
        :param pulumi.Input[str] external_provider: String, the external provider.
        :param pulumi.Input[bool] is_admin: Boolean, defaults to false.  Whether to enable administrative privileges
        :param pulumi.Input[bool] is_external: Boolean, defaults to false. Whether a user has access only to some internal or private projects. External users can only access projects to which they are explicitly granted access.
        :param pulumi.Input[str] name: The name of the user.
        :param pulumi.Input[int] namespace_id: The ID of the user's namespace. Available since GitLab 14.10.
        :param pulumi.Input[str] note: The note associated to the user.
        :param pulumi.Input[str] password: The password of the user.
        :param pulumi.Input[int] projects_limit: Integer, defaults to 0.  Number of projects user can create.
        :param pulumi.Input[bool] reset_password: Boolean, defaults to false. Send user password reset link.
        :param pulumi.Input[bool] skip_confirmation: Boolean, defaults to true. Whether to skip confirmation.
        :param pulumi.Input[str] state: String, defaults to 'active'. The state of the user account. Valid values are `active`, `deactivated`, `blocked`.
        :param pulumi.Input[str] username: The username of the user.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _UserState.__new__(_UserState)

        __props__.__dict__["can_create_group"] = can_create_group
        __props__.__dict__["email"] = email
        __props__.__dict__["extern_uid"] = extern_uid
        __props__.__dict__["external_provider"] = external_provider
        __props__.__dict__["is_admin"] = is_admin
        __props__.__dict__["is_external"] = is_external
        __props__.__dict__["name"] = name
        __props__.__dict__["namespace_id"] = namespace_id
        __props__.__dict__["note"] = note
        __props__.__dict__["password"] = password
        __props__.__dict__["projects_limit"] = projects_limit
        __props__.__dict__["reset_password"] = reset_password
        __props__.__dict__["skip_confirmation"] = skip_confirmation
        __props__.__dict__["state"] = state
        __props__.__dict__["username"] = username
        return User(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="canCreateGroup")
    def can_create_group(self) -> pulumi.Output[Optional[bool]]:
        """
        Boolean, defaults to false. Whether to allow the user to create groups.
        """
        return pulumi.get(self, "can_create_group")

    @property
    @pulumi.getter
    def email(self) -> pulumi.Output[str]:
        """
        The e-mail address of the user.
        """
        return pulumi.get(self, "email")

    @property
    @pulumi.getter(name="externUid")
    def extern_uid(self) -> pulumi.Output[Optional[str]]:
        """
        String, a specific external authentication provider UID.
        """
        return pulumi.get(self, "extern_uid")

    @property
    @pulumi.getter(name="externalProvider")
    def external_provider(self) -> pulumi.Output[Optional[str]]:
        """
        String, the external provider.
        """
        return pulumi.get(self, "external_provider")

    @property
    @pulumi.getter(name="isAdmin")
    def is_admin(self) -> pulumi.Output[Optional[bool]]:
        """
        Boolean, defaults to false.  Whether to enable administrative privileges
        """
        return pulumi.get(self, "is_admin")

    @property
    @pulumi.getter(name="isExternal")
    def is_external(self) -> pulumi.Output[Optional[bool]]:
        """
        Boolean, defaults to false. Whether a user has access only to some internal or private projects. External users can only access projects to which they are explicitly granted access.
        """
        return pulumi.get(self, "is_external")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        The name of the user.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="namespaceId")
    def namespace_id(self) -> pulumi.Output[int]:
        """
        The ID of the user's namespace. Available since GitLab 14.10.
        """
        return pulumi.get(self, "namespace_id")

    @property
    @pulumi.getter
    def note(self) -> pulumi.Output[Optional[str]]:
        """
        The note associated to the user.
        """
        return pulumi.get(self, "note")

    @property
    @pulumi.getter
    def password(self) -> pulumi.Output[Optional[str]]:
        """
        The password of the user.
        """
        return pulumi.get(self, "password")

    @property
    @pulumi.getter(name="projectsLimit")
    def projects_limit(self) -> pulumi.Output[Optional[int]]:
        """
        Integer, defaults to 0.  Number of projects user can create.
        """
        return pulumi.get(self, "projects_limit")

    @property
    @pulumi.getter(name="resetPassword")
    def reset_password(self) -> pulumi.Output[Optional[bool]]:
        """
        Boolean, defaults to false. Send user password reset link.
        """
        return pulumi.get(self, "reset_password")

    @property
    @pulumi.getter(name="skipConfirmation")
    def skip_confirmation(self) -> pulumi.Output[Optional[bool]]:
        """
        Boolean, defaults to true. Whether to skip confirmation.
        """
        return pulumi.get(self, "skip_confirmation")

    @property
    @pulumi.getter
    def state(self) -> pulumi.Output[Optional[str]]:
        """
        String, defaults to 'active'. The state of the user account. Valid values are `active`, `deactivated`, `blocked`.
        """
        return pulumi.get(self, "state")

    @property
    @pulumi.getter
    def username(self) -> pulumi.Output[str]:
        """
        The username of the user.
        """
        return pulumi.get(self, "username")

